@@ -56,6 +56,10 @@ DWIDGET_USE_NAMESPACE
 #define EGLAPIENTRY  KHRONOS_APIENTRY
 #endif
 
+#ifndef GLAPIENTRY
+#define GLAPIENTRY
+#endif
+
 static const char *vs_blend = R"(
 attribute vec2 position;
 attribute vec2 vTexCoord;
@@ -79,7 +83,9 @@ void main() {
 )";
 
 static const char* fs_blend_wayland = R"(
+#ifdef GL_ES
 precision mediump float;
+#endif
 varying vec2 texCoord;
 
 uniform sampler2D movie;
@@ -117,7 +123,9 @@ void main() {
 )";
 
 static const char* fs_blend_corner_wayland = R"(
+#ifdef GL_ES
 precision mediump float;
+#endif
 varying vec2 maskCoord;
 varying vec2 texCoord;
 
@@ -154,7 +162,9 @@ void main() {
 )";
 
 static const char* fs_code_wayland = R"(
+#ifdef GL_ES
 precision mediump float;
+#endif
 varying vec2 texCoord;
 
 uniform sampler2D sampler;
@@ -179,7 +189,9 @@ void main() {
 )";
 
 static const char* fs_corner_code_wayland = R"(
+#ifdef GL_ES
 precision mediump float;
+#endif
 varying vec2 texCoord;
 
 uniform sampler2D corner;
@@ -432,7 +444,7 @@ namespace dmr {
         pixmap=pixmap.fromImage(img);
 
         QPixmap pixmap2;
-        QImage img1=utils::LoadHiDPIImage(":/resources/icons/dark/init-splash.svg");
+        QImage img1=QIcon::fromTheme("deepin-movie").pixmap(130, 130).toImage();
         pixmap2=pixmap2.fromImage(img1);
 
         QPainter painter(&pixmap);
@@ -447,7 +459,7 @@ namespace dmr {
         pixmap3=pixmap3.fromImage(image);
 
         QPixmap pixmap4;
-        QImage img2=utils::LoadHiDPIImage(":/resources/icons/dark/init-splash.svg");
+        QImage img2=QIcon::fromTheme("deepin-movie").pixmap(130, 130).toImage();
         pixmap4=pixmap4.fromImage(img2);
 
         QPainter painter1(&pixmap3);
@@ -491,7 +503,11 @@ namespace dmr {
 #endif
 #endif
 
+#if MPV_CLIENT_API_VERSION < MPV_MAKE_VERSION(2,0)
         mpv_opengl_init_params gl_init_params = { get_proc_address, nullptr, nullptr };
+#else
+        mpv_opengl_init_params gl_init_params = { get_proc_address, nullptr };
+#endif
         //int adv_control = 1;
         mpv_render_param params[] = {
             {MPV_RENDER_PARAM_API_TYPE, const_cast<char*>(MPV_RENDER_API_TYPE_OPENGL)},
@@ -764,6 +780,7 @@ namespace dmr {
         m_renderCreat = nullptr;
         m_renderContexRender = nullptr;
         m_renderContextUpdate = nullptr;
+        m_bRawFormat = false;
     }
 
     /*not used yet*/
@@ -824,7 +841,7 @@ namespace dmr {
                     m_pGlProgBlend->release();
                 }
 
-                {
+                if (m_bDoRoundedClipping) {
                     pGLFunction->glBlendFunc(GL_SRC_ALPHA, GL_ZERO);
                     // blend corners
                     //QOpenGLVertexArrayObject::Binder vaoBind(&m_vaoCorner);
@@ -861,7 +878,50 @@ namespace dmr {
 
                 pGLFunction->glDisable(GL_BLEND);
             }
-
+#ifdef __x86_64__
+            QWidget *topWidget = topLevelWidget();
+            if(topWidget && (topWidget->isFullScreen())) {//全屏状态播放时更新显示进度
+                QString time_text = QTime::currentTime().toString("hh:mm");
+                QRect rectTime = QRect(rect().width() - 90, 0, 90, 40);
+                QPainter painter;
+                painter.begin(this);
+                QPen pen;
+                pen.setColor(QColor(255, 255, 255, 255 * .4));
+                painter.setPen(pen);
+                QFontMetrics fm(font());
+                auto fr = fm.boundingRect(time_text);
+                fr.moveCenter(rectTime.center());
+                //显示系统时间
+                painter.drawText(fr,time_text);
+                QPoint pos((rectTime.topLeft().x() + 20), rectTime.topLeft().y() + rectTime.height() - 5);
+                int pert = qMin(m_pert * 10, 10.0);
+                for (int i = 0; i < 10; i++) {//显示影院视频播放进度
+                    if (i >= pert) {
+                        painter.fillRect(QRect(pos, QSize(3, 3)), QColor(255, 255, 255, 255 * .25));
+                    } else {
+                        painter.fillRect(QRect(pos, QSize(3, 3)), QColor(255, 255, 255, 255 * .5));
+                    }
+                    pos.rx() += 5;
+                }
+                QRect rectMovieTime = QRect(rect().width() - 175, 46, 175, 20);
+                if(m_strPlayTime.isNull() || m_strPlayTime.isEmpty()) return;
+                QPalette Palette;
+                pen.setColor(Palette.color(QPalette::Text));
+                if (m_bRawFormat) {
+                    if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+                        pen.setColor(QColor(0, 0, 0, 40));
+                    } else {
+                        pen.setColor(QColor(255, 255, 255, 40));
+                    }
+                }
+                painter.setPen(pen);
+                fr = fm.boundingRect(m_strPlayTime);
+                fr.moveCenter(rectMovieTime.center());
+                //显示影院视频播放时间与总时间
+                painter.drawText(fr,m_strPlayTime);
+                painter.end();
+            }
+#endif
         } else {
             pGLFunction->glEnable(GL_BLEND);
             pGLFunction->glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
@@ -884,13 +944,16 @@ namespace dmr {
                     m_vbo.bind();
                     m_pGlProg->bind();
                     m_pGlProg->setUniformValue("bg", color);
-
-                    QOpenGLTexture *pGLTexture = m_pLightTex;
-                    DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
-                    //                if (qApp->theme() == "dark") {
-                    if (themeType == DGuiApplicationHelper::DarkType) {
-                        pGLTexture = m_pDarkTex;
-                    }
+                    prepareSplashImages();
+                    QOpenGLTexture *pGLTexture;
+                    m_pLightTex->setData(m_imgBgLight);
+                    pGLTexture = m_pLightTex;
+                    //和产品、ui商议深色主题下去除深色背景效果
+//                    DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
+//                    //                if (qApp->theme() == "dark") {
+//                    if (themeType == DGuiApplicationHelper::DarkType) {
+//                        pGLTexture = m_pDarkTex;
+//                    }
                     pGLTexture->bind();
                     pGLFunction->glActiveTexture(GL_TEXTURE0);
                     pGLFunction->glDrawArrays(GL_TRIANGLES, 0, 6);
@@ -932,6 +995,22 @@ namespace dmr {
 
         }
     }
+#ifdef __x86_64__
+    void MpvGLWidget::updateMovieProgress(qint64 duration, qint64 pos)
+    {
+        if (pos > duration)
+            pos = duration;
+        m_pert = (qreal)pos / duration;//更新影院播放进度
+        QString sCurtime = QString("%1 %2").arg(utils::Time2str(pos)).arg("/ ");
+        QString stime = QString("%1").arg(utils::Time2str(duration));
+        m_strPlayTime = sCurtime + stime;//更新影院当前播放时长
+    }
+#endif
+  
+    void MpvGLWidget::setRawFormatFlag(bool bRawFormat)
+    {
+        m_bRawFormat = bRawFormat;
+    }
 
     void MpvGLWidget::setPlaying(bool bFalse)
     {
@@ -958,11 +1037,12 @@ namespace dmr {
     void MpvGLWidget::initMpvFuns()
     {
         qInfo() << "MpvGLWidget开始initMpvFuns";
-        m_callback = reinterpret_cast<mpv_render_contextSet_update_callback>(QLibrary::resolve(libPath("libmpv.so.1"), "mpv_render_context_set_update_callback"));
-        m_context_report = reinterpret_cast<mpv_render_contextReport_swap>(QLibrary::resolve(libPath("libmpv.so.1"), "mpv_render_context_report_swap"));
-        m_renderContex = reinterpret_cast<mpv_renderContext_free>(QLibrary::resolve(libPath("libmpv.so.1"), "mpv_render_context_free"));
-        m_renderCreat = reinterpret_cast<mpv_renderContext_create>(QLibrary::resolve(libPath("libmpv.so.1"), "mpv_render_context_create"));
-        m_renderContexRender = reinterpret_cast<mpv_renderContext_render>(QLibrary::resolve(libPath("libmpv.so.1"), "mpv_render_context_render"));
-        m_renderContextUpdate = reinterpret_cast<mpv_renderContext_update>(QLibrary::resolve(libPath("libmpv.so.1"), "mpv_render_context_update"));
+        QLibrary mpvLibrary(libPath("libmpv.so.1"));
+        m_callback = reinterpret_cast<mpv_render_contextSet_update_callback>(mpvLibrary.resolve("mpv_render_context_set_update_callback"));
+        m_context_report = reinterpret_cast<mpv_render_contextReport_swap>(mpvLibrary.resolve("mpv_render_context_report_swap"));
+        m_renderContex = reinterpret_cast<mpv_renderContext_free>(mpvLibrary.resolve("mpv_render_context_free"));
+        m_renderCreat = reinterpret_cast<mpv_renderContext_create>(mpvLibrary.resolve("mpv_render_context_create"));
+        m_renderContexRender = reinterpret_cast<mpv_renderContext_render>(mpvLibrary.resolve("mpv_render_context_render"));
+        m_renderContextUpdate = reinterpret_cast<mpv_renderContext_update>(mpvLibrary.resolve("mpv_render_context_update"));
     }
 }
