@@ -74,8 +74,10 @@ static QString libPath(const QString &sLib)
         list.sort();
     }
 
-    Q_ASSERT(list.size() > 0);
-    return list.last();
+    if(list.size() > 0)
+        return list.last();
+    else
+        return QString();
 }
 
 class MpvHandle
@@ -117,6 +119,13 @@ namespace dmr {
 using namespace mpv::qt;
 class MpvGLWidget;
 
+//解码模式
+enum DecodeMode {
+    AUTO = 0,
+    HARDWARE,
+    SOFTWARE
+};
+
 /**
  * @file 封装mpv播放引擎
  */
@@ -137,10 +146,24 @@ class MpvProxy: public Backend
 signals:
     void has_mpv_events();
 
+    /**
+    * @brief 崩溃检测
+    */
+    void crashCheck();
+
 public:
     explicit MpvProxy(QWidget *parent = 0);
     virtual ~MpvProxy();
 
+    /**
+     * @brief 设置解码模式
+     */
+    void setDecodeModel(const QVariant &value);
+    /**
+     * @brief 刷新解码方式
+     */
+    void refreshDecode();
+
 //    //add by heyi
     /**
      * @brief initMpvFuns   初始化MPV动态调用库函数
@@ -155,6 +178,11 @@ public:
      * @brief 初始化mpv设置
      */
     void initSetting();
+    /**
+     * @brief updateRoundClip 更新opengl绘制圆角
+     * @param roundClip 是否为圆角
+     */
+    void updateRoundClip(bool roundClip);
     /**
      * @brief 正在播放影片的影片信息
      */
@@ -366,6 +394,18 @@ public slots:
 
 protected:
     void initMember();      //初始化成员变量
+    /**
+     * @brief initMpvFuns   初始化gpuinfo硬解探测函数
+     */
+    void initGpuInfoFuns();
+    /**
+     * @brief 是否支持硬件解码
+     */
+    bool isSurportHardWareDecode(const QString sDecodeName, const int &nVideoWidth, const int &nVideoHeight);
+    /**
+     * @brief 获取探测解码值
+     */
+    int getDecodeProbeValue(const QString sDecodeName);
     void resizeEvent(QResizeEvent *pEvent) override;
     void showEvent(QShowEvent *pEvent) override;
 
@@ -408,6 +448,8 @@ private:
     mpv_setWakeup_callback m_setWakeupCallback;
     mpvinitialize m_initialize;
     mpv_freeNode_contents m_freeNodecontents;
+    void *m_gpuInfo; //解码探测函数指针
+
 
     MpvHandle m_handle;                    //mpv句柄
     MpvGLWidget *m_pMpvGLwidget;           //opengl窗口
@@ -419,13 +461,11 @@ private:
     QList<qint64> m_listBurstPoints;       //存储连拍截图截图位置
 
     qint64 m_nBurstStart;                  //记录连拍截图次数
-    qint64 m_nStartPlayDuration;           //mpv播放视频的起始位置
 
     bool m_bPendingSeek;
     bool m_bInBurstShotting;               //是否停止连拍截图
 
     bool m_bPolling;
-    bool m_bExternalSubJustLoaded;         //是否加载在线字幕
     bool m_bConnectStateChange;
     bool m_bPauseOnStart;                  //mpv是否在暂停中
     bool m_bIsJingJia;                     //是否在景嘉微平台上
@@ -436,6 +476,9 @@ private:
     QVector<QVariant> m_vecWaitCommand;    //等待mpv初始化后设置的参数
     //mpv播放配置
     QMap<QString, QString> *m_pConfig;
+
+    //解码模式
+    DecodeMode m_decodeMode {DecodeMode::AUTO};
 };
 
 }
