@@ -34,6 +34,8 @@
 #include <QtCore>
 #include <QtGui>
 
+#include <DStandardPaths>
+
 #include "dmr_settings.h"
 #include "compositing_manager.h"
 #include "utils.h"
@@ -41,36 +43,32 @@
 
 namespace dmr {
 using namespace Dtk::Core;
-static Settings *s_pTheSettings = nullptr;
-
+Settings *Settings::m_pTheSettings = nullptr;
 Settings &Settings::get()
 {
-    if (!s_pTheSettings) {
-        s_pTheSettings = new Settings;
+    if (!m_pTheSettings) {
+        m_pTheSettings = new Settings;
     }
 
-    return *s_pTheSettings;
+    return *m_pTheSettings;
 }
 
 Settings::Settings()
-    : QObject(nullptr), m_sConfigPath("%1/%2/%3/config.conf")
+    : QObject(nullptr)
 {
-    m_sConfigPath = m_sConfigPath
-                    .arg(QStandardPaths::writableLocation(QStandardPaths::ConfigLocation))
-                    .arg(qApp->organizationName())
-                    .arg(qApp->applicationName());
+    m_sConfigPath = DStandardPaths::writableLocation(QStandardPaths::AppConfigLocation);
+    m_sConfigPath += "/config.conf";
     qInfo() << "configPath" << m_sConfigPath;
     QSettingBackend *pBackend = new QSettingBackend(m_sConfigPath);
-#if defined (__mips__) || defined (__sw_64__) || defined ( __aarch64__)
-    /*if (!CompositingManager::get().composited()) {
-        m_pSettings = DSettings::fromJsonFile(":/resources/data/lowEffectSettings.json");
+    if(!CompositingManager::isMpvExists()) {
+        m_pSettings = DSettings::fromJsonFile(":/resources/data/GstSettings.json");
     } else {
-        m_pSettings = DSettings::fromJsonFile(":/resources/data/settings.json");
-    }*/
+#if defined (__mips__) || defined (__sw_64__) || defined ( __aarch64__)
     m_pSettings = DSettings::fromJsonFile(":/resources/data/lowEffectSettings.json");
 #else
     m_pSettings = DSettings::fromJsonFile(":/resources/data/settings.json");
 #endif
+    }
     m_pSettings->setBackend(pBackend);
 
     connect(m_pSettings, &DSettings::valueChanged,
@@ -79,6 +77,14 @@ Settings::Settings()
             emit shortcutsChanged(key, value);
         else if (key.startsWith("base.play.playmode"))
             emit defaultplaymodechanged(key, value);
+        else if (key.startsWith("base.decode.select")) {
+            //设置解码模式
+            emit setDecodeModel(key, value);
+            //刷新解码模式
+            emit refreshDecode();
+            //崩溃检测
+            crashCheck();
+        }
         else if (key.startsWith("base.play.hwaccel"))
             emit hwaccelModeChanged(key, value);
         else if (key.startsWith("base.play.mute"))
@@ -108,16 +114,18 @@ Settings::Settings()
     hwaccelFamily->setData("items", hwaccelDatabase);
 
     QFontDatabase fontDatabase;
-    auto fontFamliy = m_pSettings->option("subtitle.font.family");
-    fontFamliy->setData("items", fontDatabase.families());
-    //fontFamliy->setValue(0);
+    QPointer<DSettingsOption> fontFamliy = m_pSettings->option("subtitle.font.family");
+    if(fontFamliy) {
+        fontFamliy->setData("items", fontDatabase.families());
+    }
+
     QFileInfo fi("/dev/mwv206_0");      //景嘉微显卡默认不勾选预览
     if (fi.exists() && utils::check_wayland_env()) {
         setInternalOption("mousepreview", false);
     }
 }
 
-static QString flag2key(Settings::Flag f)
+QString Settings::flag2key(Settings::Flag f)
 {
     switch (f) {
     case Settings::Flag::ClearWhenQuit:
@@ -208,8 +216,10 @@ QString Settings::screenshotLocation()
 
 QString Settings::screenshotNameTemplate()
 {
-    return tr("%1/Movie%2.jpg").arg(screenshotLocation())
-           .arg(QDateTime::currentDateTime().toString("yyyyMMddhhmmss"));
+    QString strMovie = QObject::tr("Movie");
+    QString path = screenshotLocation() + QDir::separator() + strMovie +
+            QDateTime::currentDateTime().toString("yyyyMMddhhmmss") + QString(".jpg");
+    return path;
 }
 
 //cppcheck 单元测试使用
@@ -219,12 +229,27 @@ QString Settings::screenshotNameSeqTemplate()
            .arg(QDateTime::currentDateTime().toString("yyyyMMddhhmmss"));
 }
 
+void Settings::onSetCrash()
+{
+    settings()->setOption(QString("set.start.crash"),false);
+    settings()->sync();
+}
+
 void Settings::setGeneralOption(const QString &sOpt, const QVariant &var)
 {
     settings()->setOption(QString("base.general.%1").arg(sOpt), var);
     settings()->sync();
 }
 
+void Settings::crashCheck()
+{
+    //重置崩溃检测状态位
+    settings()->setOption(QString("set.start.crash"),true);
+    settings()->sync();
+    //崩溃检测
+    QTimer::singleShot(1000, this, &Settings::onSetCrash);
+}
+
 QVariant Settings::generalOption(const QString &sOpt)
 {
     return settings()->getOption(QString("base.general.%1").arg(sOpt));
@@ -252,4 +277,3 @@ bool Settings::disableInterop()
 }
 
 }
-
