@@ -71,6 +71,16 @@ signals:
      * @param 配置的值
      */
     void defaultplaymodechanged(const QString &, const QVariant &);
+    /**
+      * @brief base.decode.select 配置值变化后发送的信号
+      * @param base.decode.select 下的某一配置
+      * @param 配置的值
+      */
+    void setDecodeModel(const QString &, const QVariant &);
+    /**
+      * @brief 刷新解码方式
+      */
+    void refreshDecode();
     /**
      * @brief base.play.mute配置值变化后发送的信号
      * @param base.play.mute下的某一配置
@@ -216,12 +226,29 @@ public:
      * @return 截图文件名
      */
     QString screenshotNameSeqTemplate();
+    /**
+     * @brief 获取键值
+     * @return 键值
+     */
+    static QString flag2key(Settings::Flag f);
+
+
+public slots:
+    /**
+     * @brief 崩溃检测
+     */
+    void crashCheck();
+    /**
+     * @brief 设置崩溃状态
+     */
+    void onSetCrash();
 
 private:
     Settings();
 
     QPointer<DSettings> m_pSettings;   ///DSetting指针
     QString m_sConfigPath;             ///配置文件路径
+    static Settings *m_pTheSettings;   ///单例唯一实例
 };
 
 }
