@@ -1,4 +1,4 @@
-/* 
+/*
  * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -35,38 +35,64 @@
 namespace dmr {
 
 // Virtual button codes that are not defined by X11.
-#define Button1			1
-#define Button2			2
-#define Button3			3
-#define WheelUp			4
-#define WheelDown		5
-#define WheelLeft		6
-#define WheelRight		7
-#define XButton1		8
-#define XButton2		9
-
+#define Button1         1
+#define Button2         2
+#define Button3         3
+#define WheelUp         4
+#define WheelDown       5
+#define WheelLeft       6
+#define WheelRight      7
+#define XButton1        8
+#define XButton2        9
+/**
+ * @file x11事件过滤器线程
+ */
 class EventMonitor : public QThread
 {
     Q_OBJECT
 
 public:
-    EventMonitor(QObject *parent = 0);
+    explicit EventMonitor(QObject *parent = nullptr);
+    /**
+     * @brief 事件处理函数，处理点击事件
+     */
     void handleRecordEvent(void *);
-
+    /**
+     * @brief 应用进入激活状态
+     */
     void resumeRecording();
+    /**
+     * @brief 应用失去选中状态
+     */
     void suspendRecording();
-    
-signals:
-    void buttonedPress(int x, int y);
-    void buttonedDrag(int x, int y);
-    void buttonedRelease(int x, int y);
 
+signals:
+    /**
+     * @brief 鼠标按下信号
+     * @param 按下的横坐标
+     * @param 纵坐标
+     */
+    void buttonedPress(int nPosX, int nPosY);
+    /**
+     * @brief 鼠标拖动信号
+     * @param 拖动的横坐标
+     * @param 纵坐标
+     */
+    void buttonedDrag(int nPosX, int nPosY);
+    /**
+     * @brief 鼠标释放信号
+     * @param 按下的横坐标
+     * @param 纵坐标
+     */
+    void buttonedRelease(int nPosX, int nPosY);
+
+//cppcheck 误报
 protected:
     void run();
-    
+
 private:
-    bool isPress;
-    QAtomicInt _recording {1};
+    bool m_bIsPress;            ///记录鼠标是否按下标志位
+    QAtomicInt m_recording {1}; ///记录应用是否是激活状态
 };
 
 }
