@@ -47,6 +47,7 @@
 #include "diskcheckthread.h"
 #include "actions.h"
 #include "online_sub.h"
+#include "compositing_manager.h"
 
 class Presenter;
 
@@ -80,7 +81,6 @@ class PlaylistWidget;
 class PlayerEngine;
 class NotificationWidget;
 class MovieProgressIndicator;
-class MainWindowPropertyMonitor;
 class MovieWidget;
 
 class IconButton: public DPushButton
@@ -125,6 +125,95 @@ private:
     int m_nThemeType;
 };
 
+class MessageWindow: public QWidget
+{
+    Q_OBJECT
+public:
+    explicit MessageWindow(QWidget *parent = nullptr):
+        QWidget(parent)
+    {
+        setWindowFlags(Qt::FramelessWindowHint);
+
+        m_pTimer = new QTimer(this);
+
+        setFixedHeight(40);
+        QHBoxLayout *mainLayout = new QHBoxLayout;
+        setLayout(mainLayout);
+        mainLayout->setContentsMargins(12, 3, 0, 0);
+        mainLayout->setSpacing(10);
+
+        m_pIconBtn = new DIconButton(this);
+        m_pTextLabel = new DLabel(this);
+
+        m_pIconBtn->setFlat(true);
+        m_pIconBtn->setFocusPolicy(Qt::NoFocus);
+        m_pIconBtn->setAttribute(Qt::WA_TransparentForMouseEvents);
+        //宽度太小导致截图失败图表被裁剪
+        m_pIconBtn->setFixedSize(30, 30);
+        m_pIconBtn->setIconSize(QSize(30, 30));
+
+        m_pTextLabel->setWordWrap(true);
+        //DIconButton中icon尺寸与button尺寸不一致，导致图表与问题不对齐
+        m_pTextLabel->setFixedHeight(25);
+        m_pTextLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+
+        mainLayout->addWidget(m_pIconBtn);
+        mainLayout->addWidget(m_pTextLabel);
+
+        m_pTimer->setInterval(4000);
+        m_pTimer->setSingleShot(true);
+        connect(m_pTimer, &QTimer::timeout, this, &QWidget::close);
+    }
+
+    void setIcon(const QIcon &ico)
+    {
+        m_pIconBtn->setIcon(ico);
+    }
+
+    void setMessage(const QString &str)
+    {
+        m_pTextLabel->setText(str);
+    }
+protected:
+    void showEvent(QShowEvent *event)
+    {
+        if (m_pTimer) {
+            m_pTimer->start();
+        }
+    }
+private:
+    void paintEvent(QPaintEvent *event) override
+    {
+        const float fRadius = 18;
+        QPainter painter(this);
+        painter.setRenderHint(QPainter::Antialiasing);
+
+        bool bLight = (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType());
+        QColor color = QColor(37, 37, 37);
+        if (bLight) {
+            color = QColor(247, 247, 247);
+        }
+
+#if defined(__arrch64__) || defined(__mips__)
+        painter.fillRect(rect(), color);
+#else
+        if (!CompositingManager::get().composited()) {
+            painter.fillRect(rect(), color);
+        } else {
+            painter.fillRect(rect(), Qt::transparent);
+            QPainterPath painterPath;
+            painterPath.addRoundedRect(rect(), static_cast<qreal>(fRadius), static_cast<qreal>(fRadius));
+            painter.fillPath(painterPath, color);
+        }
+#endif
+        QWidget::paintEvent(event);
+    }
+private:
+    QTimer *m_pTimer {nullptr};
+    DIconButton *m_pIconBtn {nullptr};
+    DLabel *m_pTextLabel{nullptr};
+};
+
 /**
  * @file 主窗口，负责显示和交互
  */
@@ -154,6 +243,14 @@ signals:
      * @brief 播放速度菜单是否可用信号
      */
     void playSpeedMenuEnable(bool);
+    /**
+     * @brief 字幕菜单是否可用信号
+     */
+    void subtitleMenuEnable(bool);
+    /**
+     * @brief 窗口特效变化信号
+     */
+    void WMChanged(bool isWM);
 public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
@@ -215,12 +312,10 @@ public:
     void capturedMousePressEvent(QMouseEvent *pEvent);
     void capturedMouseReleaseEvent(QMouseEvent *pEvent);
     void capturedKeyEvent(QKeyEvent *pEvent);
-    void syncStaysOnTop();
     void updateGeometryNotification(const QSize &size);
     void updateContentGeometry(const QRect &rect);
     static QString lastOpenedPath();
     void reflectActionToUI(ActionFactory::ActionKind);
-    bool set_playlistopen_clicktogglepause(bool bPlaylistopen);
     NotificationWidget *get_nwComm();
     /**
      * @brief 在读取光盘的时候，直接把光盘挂载点的路径加入到播放列表中
@@ -237,11 +332,9 @@ public:
     QString padLoadPath();
 
 #ifdef USE_TEST
-    void testMprisapp();
     void testCdrom();
     void setCurrentHwdec(QString);
 #endif
-    void setShowSetting(bool);
     void updateGeometry(CornerEdge edge, QPoint pos);
     void setPresenter(Presenter *);
     /**
@@ -260,9 +353,8 @@ public slots:
      * @brief 根据url地址播放影片
      * @param 影片路径
      */
-    void play(const QUrl &url);
-
-    void playList(const QList<QString> &listFiles);
+    void play(const QList<QString> &listFiles);
+    void slotFinishedAddFiles(QList<QUrl>);
     void updateProxyGeometry();
     void suspendToolsWindow();
     void resumeToolsWindow();
@@ -271,9 +363,14 @@ public slots:
     void checkErrorMpvLogsChanged(const QString sPrefix, const QString sText);
     void checkWarningMpvLogsChanged(const QString sPrefix, const QString sText);
     void slotdefaultplaymodechanged(const QString &sKey, const QVariant &value);
-#if defined (__aarch64__) || defined (__mips__)
-    void syncPostion();
-#endif
+    /**
+    * @brief 设置解码模式
+    */
+    void onSetDecodeModel(const QString &key, const QVariant &value);
+    /**
+    * @brief 刷新解码模式
+    */
+    void onRefreshDecode();
     /**
      * @brief 设置窗口顶层
      */
@@ -309,9 +406,12 @@ public slots:
      */
     //void slotAwaacelModeChanged(const QString &sKey, const QVariant &value);
     /**
-     * @brief 用于测试触屏效果
+     * @brief 音量改变槽函数
      */
     void slotVolumeChanged(int nVolume);
+    void slotWMChanged(QString msg);
+    void slotMediaError();
+
 protected:
     void showEvent(QShowEvent *pEvent) override;
     void hideEvent(QHideEvent *pEvent) override;
@@ -323,7 +423,6 @@ protected:
     void mouseReleaseEvent(QMouseEvent *pEvent) override;
     void focusInEvent(QFocusEvent *pEvent) override;
     void wheelEvent(QWheelEvent *pEvent) override;
-
     void keyPressEvent(QKeyEvent *pEvent) override;
     void keyReleaseEvent(QKeyEvent *pEvent) override;
     void moveEvent(QMoveEvent *ev) override;
@@ -332,7 +431,6 @@ protected:
     void dragEnterEvent(QDragEnterEvent *pEvent) override;
     void dragMoveEvent(QDragMoveEvent *pEvent) override;
     void dropEvent(QDropEvent *pEvent) override;
-
     bool event(QEvent *pEvent) override;
     void leaveEvent(QEvent *pEvent) override;
 
@@ -347,9 +445,7 @@ protected slots:
     void animatePlayState();
     void resizeByConstraints(bool bForceCentered = false);
     void onWindowStateChanged();
-
-    void miniButtonClicked(QString sId);
-
+    void miniButtonClicked(const QString &sId);
     void startBurstShooting();
     void onBurstScreenshot(const QImage &imgFrame, qint64 timestamp);
     void delayedMouseReleaseHandler();
@@ -361,14 +457,17 @@ protected slots:
 
     void updateShadow();
 #endif
-    void updateMiniBtnTheme(int);
     void diskRemoved(QString sDiskName);
-
     void sleepStateChanged(bool bSleep);
+    void lockStateChanged(bool bLock);
     /**
      * @brief 响应锁屏dbus信号
      */
     void onSysLockState(QString serviceName, QVariantMap key2value, QStringList);
+    void slotProperChanged(QString, QVariantMap key2value, QStringList);
+    void slotUnsupported();
+    void slotInvalidFile(QString strFileName);
+
 private:
     void initMember();
     void setupTitlebar();
@@ -376,24 +475,24 @@ private:
     DSettingsDialog *initSettings();
     void updateSizeConstraints();
     void toggleUIMode();
-
     bool insideToolsArea(const QPoint &pos);
     void switchTheme();
     bool isActionAllowed(ActionFactory::ActionKind kd, bool bFromUI, bool bIsShortcut);
     QString probeCdromDevice();
     void updateWindowTitle();
-    //void toggleShapeMask();
     void prepareSplashImages();
-    void saveWindowState();
     void loadWindowState();
     void subtitleMatchVideo(const QString &sFileName);
     void defaultplaymodeinit();
+    /**
+    * @brief 解码初始化
+    */
+    void decodeInit();
     void readSinkInputPath();
     void setAudioVolume(int);
     void setMusicMuted(bool bMuted);
     void popupAdapter(QIcon, QString);
     //void setHwaccelMode(const QVariant &value = -1);
-
     //Limit video to mini mode size
     void LimitWindowize();
     void mipsShowFullScreen();
@@ -405,7 +504,7 @@ private:
     void setMusicShortKeyState(bool bState);
 
 private:
-    DFloatingMessage *m_pPopupWid;                  ///操作提示窗
+    MessageWindow *m_pPopupWid;                     ///截图提示窗口
     QLabel *m_pFullScreenTimeLable;                 ///全屏时右上角的影片进度
     QHBoxLayout *m_pFullScreenTimeLayout;           ///右上角的影片进度框布局器
     Titlebar *m_pTitlebar;                          ///标题栏
@@ -417,15 +516,9 @@ private:
     QList<QPair<QImage, qint64>> m_listBurstShoots; ///存储连拍截图
     bool m_bInBurstShootMode;                       ///是否处于截图状态
     bool m_bPausedBeforeBurst;                      ///截图时暂停播放
-#ifdef __mips__
-    QAbstractButton *m_pMiniPlayBtn;
-    QAbstractButton *m_pMiniCloseBtn;
-    QAbstractButton *m_pMiniQuitMiniBtn;
-#else
     DIconButton *m_pMiniPlayBtn;                    ///迷你模式播放按钮
     DIconButton *m_pMiniCloseBtn;                   ///迷你模式关闭按钮
     DIconButton *m_pMiniQuitMiniBtn;                ///退出迷你模式按钮
-#endif
 
     QImage m_imgBgDark;
     QImage m_imgBgLight;
@@ -435,16 +528,12 @@ private:
     EventMonitor *m_pEventMonitor;                  ///x11事件处理器
     bool m_bMovieSwitchedInFsOrMaxed;               /// track if next/prev is triggered in fs/maximized mode
     bool m_bDelayedResizeByConstraint;
-    bool m_bLightTheme;                             ///是否是浅色主题
     bool m_bWindowAbove;                            ///是否是置顶窗口
     bool m_bMouseMoved;                             ///鼠标是否按下移动
     bool m_bMousePressed;                           ///鼠标是否安下
-    bool m_bPlaylistopen_clicktogglepause;
     double m_dPlaySpeed;                            ///当前播放速度
 
-    bool m_bQuitfullscreenstopflag;
-    bool m_bQuitfullscreenflag;
-    bool m_bMaxfornormalflag;                       ///is the window maximized
+    bool m_bQuitfullscreenflag;                     ///记录最小化前是否为播放状态
     QPoint m_posMouseOrigin;                        ///记录前一次鼠标移动点
     QPoint m_pressPoint;                            ///记录当前鼠标按下时的点
     bool m_bStartMini;                              ///开始进入迷你模式
@@ -472,17 +561,12 @@ private:
     int m_nDisplayVolume;                            ///记录播放音量
     bool m_bIsFree;                                  ///播放器是否空闲，和IDel的定义不同
     static int m_nRetryTimes;                        ///播放失败后重试次数
-    bool m_bIsJinJia;                                ///是否是景嘉微显卡
     //add by heyi 解决触屏右键菜单bug
     int m_nLastPressX;                               ///左键按下时保存的点
     int m_nLastPressY;                               ///左键按下时保存的点
     bool m_bIsTouch;                                 ///是否是触摸屏按下
     QTimer m_mousePressTimer;
-    qint64 m_nOldDuration;
-    qint64 m_nOldElapsed;
     Diskcheckthread m_diskCheckThread;
-    bool m_bClosed;                                  ///用于景嘉微显卡下过滤metacall事件
-    bool m_bIsFileLoadNotFinished;
     QStringList m_listOpenFiles;
     QString m_sCurrentHwdec;                         ///当前的硬解码模式
     bool m_bProgressChanged;                         ///进度条是否被拖动
@@ -491,27 +575,15 @@ private:
     int m_iAngleDelta;                                ///鼠标滚轮滚动的距离
     bool m_bStartAnimation;                           ///是否开始动画，如果开始不允许做其他操作
     QDBusInterface *m_pDBus;
-    MainWindowPropertyMonitor *m_pMWPM;
-    bool m_bIsFirstLoadDBus;
     Presenter *m_pPresenter;
     MovieWidget *m_pMovieWidget;
-};
-
-//窗管返回事件过滤器
-class MainWindowPropertyMonitor: public QAbstractNativeEventFilter
-{
-public:
-    explicit MainWindowPropertyMonitor(MainWindow *);
-    ~MainWindowPropertyMonitor();
-    /**
-     * @brief 事件过滤器 cppcheck 误报
-     */
-    bool nativeEventFilter(const QByteArray &eventType, void *message, long *);
-
-    MainWindow *m_pMainWindow {nullptr};
-    xcb_atom_t m_atomWMState;
-    QList<unsigned int> m_list;
-    bool m_bStart;
+    qint64 m_nFullscreenTime;                         ///全屏操作间隔时间
+    QDBusInterface *m_pWMDBus {nullptr};              ///窗口特效dbus接口
+    bool m_bIsWM {true};                              ///是否开启窗口特效
+    bool m_isSettingMiniMode{false};                  ///mini mode setting status
+    Qt::WindowStates m_preMiniWindowState {Qt::WindowNoState};  ///window state before mini mode
+    bool m_bMaximized;                                ///全屏前最大化窗口记录
+    bool m_bHaveFile;                                 ///导入是否包含文件（用于导入文件或文件夹）
 };
 };
 
