@@ -52,6 +52,8 @@
 #undef Bool
 #include "../vendor/qthelper.hpp"
 
+#define BUFFERSIZE 255
+
 typedef const char *glXGetScreenDriver_t (Display *dpy, int scrNum);
 
 static glXGetScreenDriver_t *GetScreenDriver;
@@ -62,6 +64,7 @@ namespace dmr {
 using namespace std;
 
 static CompositingManager *_compManager = nullptr;
+bool CompositingManager::m_bCanHwdec = true;
 
 #define C2Q(cs) (QString::fromUtf8((cs).c_str()))
 
@@ -90,9 +93,10 @@ public:
                     qInfo() << "match shenwei";
                     _pf = Platform::Alpha;
 
-                } else if (machine.find("mips") != string::npos) { // loongson
+                } else if (machine.find("mips") != string::npos
+                           || machine.find("loongarch64") != string::npos) { // loongson
                     qInfo() << "match loongson";
-                    _pf = Platform::Alpha;
+                    _pf = Platform::Mips;
                 } else if (machine.find("aarch64") != string::npos) { // ARM64
                     qInfo() << "match arm";
                     _pf = Platform::Arm64;
@@ -122,114 +126,64 @@ CompositingManager &CompositingManager::get()
 CompositingManager::CompositingManager()
 {
     initMember();
-#ifdef __aarch64__
+    bool isDriverLoaded = isDriverLoadedCorrectly();
+    softDecodeCheck();   //检测是否是kunpeng920（是否走软解码）
+
+    bool isI915 = false;
+    for (int id = 0; id <= 10; id++) {
+        if (!QFile::exists(QString("/sys/class/drm/card%1").arg(id))) break;
+        if (is_device_viable(id)) {
+            vector<string> drivers = {"i915"};
+            isI915 = is_card_exists(id, drivers);
+            break;
+        }
+    }
+    if (isI915) qInfo() << "is i915!";
+    m_bZXIntgraphics = isI915 ? isI915 : m_bZXIntgraphics;
+
     if (dmr::utils::check_wayland_env()) {
         _composited = true;
+        //读取配置
+        m_pMpvConfig = new QMap<QString, QString>;
+        utils::getPlayProperty("/etc/mpv/play.conf", m_pMpvConfig);
+        if (m_pMpvConfig->contains("vo")) {
+            QString value = m_pMpvConfig->find("vo").value();
+            if ("libmpv" == value) {
+                _composited = true;//libmpv只能走opengl
+            }
+        }
+        if (_platform == Platform::Arm64 && isDriverLoaded)
+            m_bHasCard = true;
         qInfo() << __func__ << "Composited is " << _composited;
         return;
     }
-#endif
-    softDecodeCheck();   //检测是否是kunpeng920（是否走软解码）
 
     _composited = false;
-    if (QGSettings::isSchemaInstalled("com.deepin.deepin-movie")) {
-        QGSettings gsettings("com.deepin.deepin-movie", "/com/deepin/deepin-movie/");
-        QString aa = gsettings.get("composited").toString();
-        if ((gsettings.get("composited").toString() == "DisableComposited"
-                || gsettings.get("composited").toString() == "EnableComposited")) {
-            if (gsettings.keys().contains("composited")) {
-                if (gsettings.get("composited").toString() == "DisableComposited") {
-                    _composited = false;
-                } else if (gsettings.get("composited").toString() == "EnableComposited") {
-                    _composited = true;
-                }
+    QGSettings gsettings("com.deepin.deepin-movie", "/com/deepin/deepin-movie/");
+    QString aa = gsettings.get("composited").toString();
+    if ((gsettings.get("composited").toString() == "DisableComposited"
+            || gsettings.get("composited").toString() == "EnableComposited")) {
+        if (gsettings.keys().contains("composited")) {
+            if (gsettings.get("composited").toString() == "DisableComposited") {
+                _composited = false;
+            } else if (gsettings.get("composited").toString() == "EnableComposited") {
+                _composited = true;
             }
-        } else {
-            if (QProcessEnvironment::systemEnvironment().value("SANDBOX") == "flatpak") {
-                _composited = QFile::exists("/dev/dri/card0");
-            } else if (isProprietaryDriver()) {
-                _composited = true;
-            } else if (isDriverLoadedCorrectly() || isDirectRendered()) {
-#ifdef __aarch64__
+        }
+    } else {
+        if (_platform == Platform::X86) {
+            if (m_bZXIntgraphics) {
                 _composited = false;
-                qInfo() << "__aarch64__  isDirectRendered";
-                if (isDriverLoadedCorrectly()) {    //如果有独立显卡
-                    _composited = true;
-                    qInfo() << "__aarch64__  isDriverLoadedCorrectly";
-                }
-#elif defined (__mips__)
-                _composited = false;
-                qInfo() << "__mips__";
-#else
-                vector<string> drivers = {"zx"};
-                m_setSpecialControls = m_setSpecialControls || is_card_exists(0, drivers);
-                _composited = true;
-                qInfo() << "__X86__";
-#endif
             } else {
-                GetScreenDriver = reinterpret_cast<glXGetScreenDriver_t *>(glXGetProcAddressARB(reinterpret_cast<const GLubyte *>("glXGetScreenDriver")));
-                if (GetScreenDriver) {
-                    const char *name = (*GetScreenDriver)(QX11Info::display(), QX11Info::appScreen());
-                    qInfo() << "dri driver: " << name;
-                    _composited = name != nullptr;
-                }
-            }
-
-#ifndef _LIBDMR_
-            auto v = CommandLineManager::get().openglMode();
-            if (v == "off") {
-                _composited = false;
-            } else if (v == "on") {
                 _composited = true;
             }
-#endif
-        }
-        qInfo() << "From gsetting, composition about opengl :" << gsettings.get("composited").toString();
-    } else { /* if(gsettings.get("composited").toString() == "Default")*/
-        if (QProcessEnvironment::systemEnvironment().value("SANDBOX") == "flatpak") {
-            _composited = QFile::exists("/dev/dri/card0");
-        } else if (isProprietaryDriver()) {
-            _composited = true;
-        } else if (isDriverLoadedCorrectly() || isDirectRendered()) {
-            _composited = true;
         } else {
-            GetScreenDriver = reinterpret_cast<glXGetScreenDriver_t *>(glXGetProcAddressARB(reinterpret_cast<const GLubyte *>("glXGetScreenDriver")));
-            if (GetScreenDriver) {
-                const char *name = (*GetScreenDriver)(QX11Info::display(), QX11Info::appScreen());
-                qInfo() << "dri driver: " << name;
-                _composited = name != nullptr;
-            }
-        }
-
-#ifndef _LIBDMR_
-        auto v = CommandLineManager::get().openglMode();
-        if (v == "off") {
+            if (_platform == Platform::Arm64 && isDriverLoaded)
+                m_bHasCard = true;
             _composited = false;
-        } else if (v == "on") {
-            _composited = true;
         }
-#endif
     }
-#ifdef MWV206_0
-    QFileInfo fi("/dev/mwv206_0"); //景嘉微显卡目前只支持vo=xv，等日后升级代码需要酌情修改。
-    if (fi.exists()) {
-        _composited = false;
-    }
-#endif
-#ifdef __mips__
-    bool bRet = QDBusInterface("com.deepin.wm", "/com/deepin/wm", "com.deepin.wm").property("compositingAllowSwitch").toBool();
-    if (!bRet) {
-        _composited = false;   //2020.3.19龙芯增加显卡需保留检测显卡方案
-    }
-#endif
-    qInfo() << "composited:" << _composited;
-#if !defined (__x86_64__)
-    if (_composited) {
-        m_bHasCard = _composited;
-        _composited = false;
-        qInfo() << "hasCard: " << m_bHasCard;
-    }
-#endif
+
     //读取配置
     m_pMpvConfig = new QMap<QString, QString>;
     utils::getPlayProperty("/etc/mpv/play.conf", m_pMpvConfig);
@@ -239,6 +193,22 @@ CompositingManager::CompositingManager()
             _composited = true;//libmpv只能走opengl
         }
     }
+    //单元测试
+#ifdef USE_TEST
+    utils::getPlayProperty("/data/source/deepin-movie-reborn/movie/play.conf", m_pMpvConfig);
+    if (m_pMpvConfig->contains("vo")) {
+        QString value = m_pMpvConfig->find("vo").value();
+        if ("libmpv" == value) {
+            _composited = true;//libmpv只能走opengl
+        } else {
+            _composited = false;//libmpv只能走opengl
+        }
+    }
+#endif
+    if(!isMpvExists())
+    {
+        _composited = true;
+    }
     qInfo() << __func__ << "Composited is " << _composited;
 }
 
@@ -304,6 +274,28 @@ bool CompositingManager::isPadSystem()
     return false;
 }
 
+bool CompositingManager::isCanHwdec()
+{
+    return m_bCanHwdec;
+}
+
+void CompositingManager::setCanHwdec(bool bCanHwdec)
+{
+    m_bCanHwdec = bCanHwdec;
+}
+
+bool CompositingManager::isMpvExists()
+{
+    QDir dir;
+    QString path  = QLibraryInfo::location(QLibraryInfo::LibrariesPath);
+    dir.setPath(path);
+    QStringList list = dir.entryList(QStringList() << (QString("libmpv.so.1") + "*"), QDir::NoDotAndDotDot | QDir::Files);
+    if (list.contains("libmpv.so.1")) {
+        return true;
+    }
+    return false;
+}
+
 bool CompositingManager::isZXIntgraphics() const
 {
     return m_bZXIntgraphics;
@@ -327,35 +319,62 @@ bool CompositingManager::runningOnNvidia()
 
 void CompositingManager::softDecodeCheck()
 {
-    QProcess uname;
-    char *data = (char *)malloc(100);
-    uname.start("cat /proc/cpuinfo");
-    if (uname.waitForStarted()) {
-        if (uname.waitForFinished()) {
-            while (uname.readLine(data, 99) > 0) {
-                QString strData(data);
-                QStringList listPara = strData.split(":");
-
-                if (listPara.size() < 2) {
-                    continue;
-                }
-
-                if (listPara.at(0).contains("model name")
-                        && listPara.at(1).contains("Kunpeng 920")) {
-                    m_bOnlySoftDecode = true;
-                }
+    //获取cpu型号
+    QFile cpuInfo("/proc/cpuinfo");
+    if (cpuInfo.open(QIODevice::ReadOnly)) {
+        QString line = cpuInfo.readLine();
+        while (!cpuInfo.atEnd()) {
+            line = cpuInfo.readLine();
+            QStringList listPara = line.split(":");
+            qInfo() << listPara;
+            if (listPara.size() < 2) {
+                continue;
+            }
+            if (listPara.at(0).contains("model name")) {
+                m_cpuModelName = listPara.at(1);
+                break;
             }
         }
+        cpuInfo.close();
     }
-    free(data);
-    //浪潮 inspur softdecode
-    QProcess inspur;
-    inspur.start("cat /sys/class/dmi/id/board_vendor");
-    if (inspur.waitForStarted() && inspur.waitForFinished()) {
-        QString drv = QString::fromUtf8(inspur.readAllStandardOutput().trimmed().constData());
-        qInfo() << "inspur check : " << drv;
-        m_bOnlySoftDecode =  m_bOnlySoftDecode || drv.contains("Inspur");
-        m_setSpecialControls = drv.contains("Ruijie");
+
+    //获取设备名
+    QFile board("/sys/class/dmi/id/board_vendor");
+    if (board.open(QIODevice::ReadOnly)) {
+        QString line = board.readLine();
+        while (!board.atEnd()) {
+            m_boardVendor = line;
+            break;
+        }
+        board.close();
+    }
+
+    if ((runningOnNvidia() && m_boardVendor.contains("Sugon"))
+            || m_cpuModelName.contains("Kunpeng 920")) {
+        m_bOnlySoftDecode = true;
+    }
+    if(m_boardVendor.toLower().contains("huawei")) {
+        m_bHasCard = true;
+    }
+
+    m_setSpecialControls = m_boardVendor.contains("Ruijie");
+
+    //判断N卡驱动版本
+    QFile nvidiaVersion("/proc/driver/nvidia/version");
+    if (nvidiaVersion.open(QIODevice::ReadOnly)) {
+        QString str = nvidiaVersion.readLine();
+        int start = str.indexOf("Module");
+        start += 6;
+        QString version = str.mid(start, 6);
+        while (version.left(1) == " ") {
+            start++;
+            version = str.mid(start, 6);
+        }
+        qInfo() << "nvidia version :" << version;
+        if (version.toFloat() >= 460.39) {
+            m_bOnlySoftDecode = true;
+        }
+        nvidiaVersion.close();
     }
 }
 
@@ -503,14 +522,13 @@ bool CompositingManager::isDriverLoadedCorrectly()
     return true;
 }
 
-//cppcheck 修改
-//void CompositingManager::overrideCompositeMode(bool useCompositing)
-//{
-//    if (_composited != useCompositing) {
-//        qInfo() << "override composited = " << useCompositing;
-//        _composited = useCompositing;
-//    }
-//}
+void CompositingManager::overrideCompositeMode(bool useCompositing)
+{
+    if (_composited != useCompositing) {
+        qInfo() << "override composited = " << useCompositing;
+        _composited = useCompositing;
+    }
+}
 
 using namespace std;
 
@@ -569,7 +587,7 @@ bool CompositingManager::isProprietaryDriver()
     for (int id = 0; id <= 10; id++) {
         if (!QFile::exists(QString("/sys/class/drm/card%1").arg(id))) break;
         if (is_device_viable(id)) {
-            vector<string> drivers = {"nvidia", "fglrx", "vmwgfx", "hibmc-drm", "radeon", "i915", "amdgpu"};
+            vector<string> drivers = {"nvidia", "fglrx", "vmwgfx", "hibmc-drm", "radeon", "i915", "amdgpu", "phytium_display"};
             return is_card_exists(id, drivers);
         }
     }
