@@ -1,5 +1,9 @@
-/* 
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
+/*
+ * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+ *
+ * Author:     xiepengfei <xiepengfei@uniontech.com>
+ *
+ * Maintainer: liuzheng <liuzheng@uniontech.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,14 +36,16 @@
 #include <dvdnav/dvdnav.h>
 
 namespace dmr {
+//add by xxj
+#ifdef heyi
 namespace dvd {
 
-QString RetrieveDVDTitle(const QString& device)
+/*QString RetrieveDVDTitle(const QString &device)
 {
-    qDebug() << "device" << device;
-    const char *title = NULL;
+    qInfo() << "device" << device;
+    const char *title = nullptr;
 
-    dvdnav_t *handle = NULL;
+    dvdnav_t *handle = nullptr;
     auto res = dvdnav_open(&handle, device.toUtf8().constData());
     if (res == DVDNAV_STATUS_ERR) {
         qWarning() << "dvdnav open " << device << "failed";
@@ -66,7 +72,7 @@ QString RetrieveDVDTitle(const QString& device)
         auto n = dvdnav_describe_title_chapters(handle, i, NULL, &duration);
         if (max_duration < duration) {
             max_duration = duration;
-            //title 
+            //title
         }
     }
 #endif
@@ -77,9 +83,9 @@ on_error:
     qWarning() << dvdnav_err_to_string(handle);
     if (handle) dvdnav_close(handle);
     return "";
-}
+}*/
 
-static std::atomic<RetrieveDvdThread*> _instance { nullptr };
+static std::atomic<RetrieveDvdThread *> _instance { nullptr };
 static QMutex _instLock;
 static QMutex _startLock;
 static QMutex _runLock;
@@ -103,9 +109,9 @@ RetrieveDvdThread *RetrieveDvdThread::get()
 {
     if (_instance == nullptr) {
         QMutexLocker lock(&_instLock);
-        if (_instance == nullptr) {
+//        if (_instance == nullptr) {
             _instance = new RetrieveDvdThread;
-        }
+//        }
     }
     return _instance;
 }
@@ -130,25 +136,27 @@ void RetrieveDvdThread::run()
         if (_quit.load()) break;
 
         auto title = getDvdMsg(m_dev);
-        qDebug() << "-----" << title;
+        qInfo() << "-----" << title;
         emit sigData(title);
     } while (false);
 }
 
 QString RetrieveDvdThread::getDvdMsg(const QString &device)
 {
-    qDebug() << "device" << device;
+    qInfo() << "device" << device;
     const char *title = nullptr;
 
     dvdnav_t *handle = nullptr;
-    auto res = dvdnav_open(&handle, device.toUtf8().constData());
+    int32_t res = 0;
+#ifndef __mips__
+    res = dvdnav_open(&handle, device.toUtf8().constData());
     if (res == DVDNAV_STATUS_ERR) {
         qCritical() << "dvdnav open " << device << "failed";
         qCritical() << dvdnav_err_to_string(handle);
         if (handle) dvdnav_close(handle);
         return "dvd open failed";
     }
-
+#endif
     int32_t nr_titles = 0;
     res = dvdnav_get_number_of_titles(handle, &nr_titles);
     if (res == DVDNAV_STATUS_ERR) {
@@ -183,6 +191,7 @@ on_error:
 }
 
 }
+#endif
 }
 
 
