@@ -40,6 +40,9 @@
 #include "mpv_proxy.h"
 #include "compositing_manager.h"
 #include "dguiapplicationhelper.h"
+#include "filefilter.h"
+#include "qtplayer_proxy.h"
+#include "eventlogutils.h"
 
 #include <QPainterPath>
 
@@ -53,9 +56,14 @@ DGUI_USE_NAMESPACE
 
 namespace dmr {
 
-const QStringList PlayerEngine::audio_filetypes = {"*.mp3", "*.ogg", "*.wav", "*.wma", "*.m4a", "*.aac", "*.ac3", "*.ape", "*.flac", "*.ra", "*.mka", "*.dts", "*.opus", "*.amr"};
+const QStringList PlayerEngine::audio_filetypes = {"*.mp3", "*.wav", "*.wma", "*.m4a", "*.aac", "*.ac3", "*.ape", "*.flac", "*.ra", "*.mka", "*.dts", "*.opus", "*.amr"};
 const QStringList PlayerEngine::video_filetypes = {
-    "*.avs2"/*支持avs2视频格式*/, "*.3g2", "*.3ga", "*.3gp", "*.3gp2", "*.3gpp", "*.amv", "*.asf", "*.asx", "*.avf", "*.avi", "*.bdm", "*.bdmv", "*.bik", "*.clpi", "*.cpi", "*.dat", "*.divx", "*.drc", "*.dv", "*.dvr-ms", "*.f4v", "*.flv", "*.gvi", "*.gxf", "*.hdmov", "*.hlv", "*.iso", "*.letv", "*.lrv", "*.m1v", "*.m2p", "*.m2t", "*.m2ts", "*.m2v", "*.m3u", "*.m3u8", "*.m4v", "*.mkv", "*.moov", "*.mov", "*.mov", "*.mp2", "*.mp2v", "*.mp4", "*.mp4v", "*.mpe", "*.mpeg", "*.mpeg1", "*.mpeg2", "*.mpeg4", "*.mpg", "*.mpl", "*.mpls", "*.mpv", "*.mpv2", "*.mqv", "*.mts", "*.mts", "*.mtv", "*.mxf", "*.mxg", "*.nsv", "*.nuv", "*.ogg", "*.ogm", "*.ogv", "*.ogx", "*.ps", "*.qt", "*.qtvr", "*.ram", "*.rec", "*.rm", "*.rm", "*.rmj", "*.rmm", "*.rms", "*.rmvb", "*.rmx", "*.rp", "*.rpl", "*.rv", "*.rvx", "*.thp", "*.tod", "*.tp", "*.trp", "*.ts", "*.tts", "*.txd", "*.vcd", "*.vdr", "*.vob", "*.vp8", "*.vro", "*.webm", "*.wm", "*.wmv", "*.wtv", "*.xesc", "*.xspf"
+    "*.3g2", "*.3ga", "*.3gp", "*.3gp2", "*.3gpp", "*.amv", "*.asf", "*.asx", "*.avf", "*.avi", "*.bdm", "*.bdmv", "*.bik", "*.clpi", "*.cpi",
+    "*.dat", "*.divx", "*.drc", "*.dv", "*.dvr-ms", "*.f4v", "*.flv", "*.gvi", "*.gxf", "*.hdmov", "*.hlv", "*.iso", "*.letv", "*.lrv", "*.m1v", "*.m2p", "*.m2t", "*.m2ts",
+    "*.m2v", "*.m3u", "*.m3u8", "*.m4v", "*.mkv", "*.moov", "*.mov", "*.mov", "*.mp2", "*.mp2v", "*.mp4", "*.mp4v", "*.mpe", "*.mpeg", "*.mpeg1", "*.mpeg2", "*.mpeg4", "*.mpg",
+    "*.mpl", "*.mpls", "*.mpv", "*.mpv2", "*.mqv", "*.mts", "*.mts", "*.mtv", "*.mxf", "*.mxg", "*.nsv", "*.nuv", "*.ogg", "*.ogm", "*.ogv", "*.ogx", "*.ps", "*.qt", "*.qtvr",
+    "*.ram", "*.rec", "*.rm", "*.rm", "*.rmj", "*.rmm", "*.rms", "*.rmvb", "*.rmx", "*.rp", "*.rpl", "*.rv", "*.rvx", "*.thp", "*.tod", "*.tp", "*.trp", "*.ts", "*.tts", "*.txd",
+    "*.vcd", "*.vdr", "*.vob", "*.vp8", "*.vro", "*.webm", "*.wm", "*.wmv", "*.wtv", "*.xesc", "*.xspf", "*.ogg",
 };
 
 const QStringList PlayerEngine::subtitle_suffixs = {"ass", "sub", "srt", "aqt", "jss", "gsub", "ssf", "ssa", "smi", "usf", "idx"};
@@ -63,10 +71,16 @@ const QStringList PlayerEngine::subtitle_suffixs = {"ass", "sub", "srt", "aqt",
 PlayerEngine::PlayerEngine(QWidget *parent)
     : QWidget(parent)
 {
+    m_bAudio = false;
+    m_stopRunningThread = false;
     auto *l = new QVBoxLayout(this);
     l->setContentsMargins(0, 0, 0, 0);
 
-    _current = new MpvProxy(this);
+    if(CompositingManager::isMpvExists()){
+        _current = new MpvProxy(this);
+    } else {
+        _current = new QtPlayerProxy(this);
+    }
     if (_current) {
         connect(_current, &Backend::stateChanged, this, &PlayerEngine::onBackendStateChanged);
         connect(_current, &Backend::tracksChanged, this, &PlayerEngine::tracksChanged);
@@ -81,9 +95,8 @@ PlayerEngine::PlayerEngine(QWidget *parent)
         connect(_current, &Backend::mpvErrorLogsChanged, this, &PlayerEngine::mpvErrorLogsChanged);
         connect(_current, &Backend::mpvWarningLogsChanged, this, &PlayerEngine::mpvWarningLogsChanged);
         connect(_current, &Backend::urlpause, this, &PlayerEngine::urlpause);
+        connect(_current, &Backend::sigMediaError, this, &PlayerEngine::sigMediaError);
         l->addWidget(_current);
-
-        //_current->firstInit();
     }
 
     connect(&_networkConfigMng, &QNetworkConfigurationManager::onlineStateChanged, this, &PlayerEngine::onlineStateChanged);
@@ -97,8 +110,6 @@ PlayerEngine::PlayerEngine(QWidget *parent)
 
     connect(&OnlineSubtitle::get(), &OnlineSubtitle::subtitlesDownloadedFor,
             this, &PlayerEngine::onSubtitlesDownloaded);
-    //heyi need
-    //addSubSearchPath(OnlineSubtitle::get().storeLocation());
 
     _playlist = new PlaylistModel(this);
     connect(_playlist, &PlaylistModel::asyncAppendFinished, this,
@@ -108,111 +119,79 @@ PlayerEngine::PlayerEngine(QWidget *parent)
 
 PlayerEngine::~PlayerEngine()
 {
-    disconnect(_playlist, nullptr, nullptr, nullptr);
-    delete _playlist;
-    _playlist = nullptr;
-
+    m_stopRunningThread = true;
+    FileFilter::instance()->stopThread();
     if (_current) {
         disconnect(_current, nullptr, nullptr, nullptr);
         delete _current;
         _current = nullptr;
     }
+    
+    if (_playlist) {
+        disconnect(_playlist, nullptr, nullptr, nullptr);
+        delete _playlist;
+        _playlist = nullptr;
+    }
     qInfo() << __func__;
 }
 
 bool PlayerEngine::isPlayableFile(const QUrl &url)
 {
-    // 根据后缀不能准确判断一个文件是否能播放
-    // 用是否包含音视频流判断更为准确
-    if (url.isLocalFile()) {
-        //return (isPlayableFile(url.path()) || isAudioFile(url.path()));
-        return (isPlayableFile(url.path()) && _playlist->isMediaFile(url.path()));
-    } else {
-        // for a networked url, there is no way to know if it's playable right now
+    if (FileFilter::instance()->isMediaFile(url)) {
         return true;
+    } else {    // 网络文件不提示
+        if(url.isLocalFile()) {
+            emit sigInvalidFile(QFileInfo(url.toLocalFile()).fileName());
+        }
+        return false;
     }
 }
 
 static QStringList suffixes;
 
-//static const QStringList &buildPlayableDatabase()
-//{
-//    static QStringList mimeTypes = {
-//        "application/ogg",
-//        "application/vnd.apple.mpegurl",
-//        "application/vnd.rn-realmedia",
-//        "application/x-extension-mp4",
-//        "application/x-flac",
-//        "application/x-matroska",
-//        "application/x-ogg",
-//        "application/xspf+xml",
-//        "image/vnd.rn-realpix",
-//        "misc/ultravox",
-//        "video/3gpp",
-//        "video/dv",
-//        "video/mp2t",
-//        "video/mp4",
-//        "video/mp4v-es",
-//        "video/mpeg",
-//        "video/msvideo",
-//        "video/ogg",
-//        "video/quicktime",
-//        "video/vnd.rn-realvideo",
-//        "video/webm",
-//        "video/x-anim",
-//        "video/x-avi",
-//        "video/x-flc",
-//        "video/x-fli",
-//        "video/x-flv",
-//        "video/x-m4v",
-//        "video/x-matroska",
-//        "video/x-mpeg",
-//        "video/x-mpeg2",
-//        "video/x-ms-afs",
-//        "video/x-ms-asf",
-//        "video/x-msvideo",
-//        "video/x-ms-wmv",
-//        "video/x-ms-wmx",
-//        "video/x-ms-wvxvideo",
-//        "video/x-nsv",
-//        "video/x-ogm+ogg",
-//        "video/x-theora",
-//        "video/x-theora+ogg",
-//        "x-content/video-dvd",
-//        "x-content/video-svcd",
-//        "x-content/video-vcd",
-//        "x-scheme-handler/mms",
-//        "x-scheme-handler/rtmp",
-//        "x-scheme-handler/rtsp",
-//    };
-
-//    if (suffixes.isEmpty()) {
-//    }
-
-//    return suffixes;
-//}
-
 bool PlayerEngine::isPlayableFile(const QString &name)
 {
-    bool bRes = true;
-    auto suffix = QString("*") + name.mid(name.lastIndexOf('.'));
-    bRes =  video_filetypes.contains(suffix, Qt::CaseInsensitive) | audio_filetypes.contains(suffix, Qt::CaseInsensitive);
-    return bRes;
+    QUrl url = FileFilter::instance()->fileTransfer(name);
+
+    if (FileFilter::instance()->isMediaFile(url))
+    {
+        return true;
+    }
+
+    if (url.isLocalFile()) {   // 网络文件不提示
+        emit sigInvalidFile(QFileInfo(url.toLocalFile()).fileName());
+        return false;
+    }
+    return  false;
 }
 
 bool PlayerEngine::isAudioFile(const QString &name)
 {
-    auto suffix = QString("*") + name.mid(name.lastIndexOf('.'));
-    return  audio_filetypes.contains(suffix, Qt::CaseInsensitive);
+    QUrl url = FileFilter::instance()->fileTransfer(name);
+
+    return FileFilter::instance()->isAudio(url);
+}
+
+bool PlayerEngine::isSubtitle(const QString &name)
+{
+    QUrl url = FileFilter::instance()->fileTransfer(name);
+
+    return FileFilter::instance()->isSubtitle(url);
 }
 
 void PlayerEngine::updateSubStyles()
 {
 #ifndef _LIBDMR_
-    auto font_opt = Settings::get().settings()->option("subtitle.font.family");
-    auto font_id = font_opt->value().toInt();
-    auto font = font_opt->data("items").toStringList()[font_id];
-    auto sz = Settings::get().settings()->option("subtitle.font.size")->value().toInt();
+    QPointer<DSettingsOption> pFontOpt = Settings::get().settings()->option("subtitle.font.family");
+    QPointer<DSettingsOption> pSizeOpt = Settings::get().settings()->option("subtitle.font.size");
+    if(!pFontOpt || !pSizeOpt)
+    {
+        return;
+    }
+
+    int fontId = pFontOpt->value().toInt();
+    int size = pSizeOpt->value().toInt();
+    QString font = pFontOpt->data("items").toStringList()[fontId];
 
     if (_state != CoreState::Idle) {
         if (_playlist->current() < 0) return;
@@ -222,19 +201,20 @@ void PlayerEngine::updateSubStyles()
             vh = _playlist->currentInfo().mi.height;
         }
         double scale = vh / 720.0;
-        sz /= scale;
+        size /= scale;
         /* magic scale number 2.0 comes from my mind, test with my eyes... */
-        sz *= 2.0;
-        qInfo() << "update sub " << font << sz;
-        updateSubStyle(font, sz);
+        size *= 2.0;
+        updateSubStyle(font, size);
     }
 #endif
 }
 
 void PlayerEngine::waitLastEnd()
 {
-    if (auto *mpv = dynamic_cast<MpvProxy *>(_current)) {
+    if (MpvProxy *mpv = dynamic_cast<MpvProxy *>(_current)) {
         mpv->pollingEndOfPlayback();
+    }else if (QtPlayerProxy *qtPlayer = dynamic_cast<QtPlayerProxy *>(_current)) {
+        qtPlayer->pollingEndOfPlayback();
     }
 }
 
@@ -242,13 +222,16 @@ void PlayerEngine::onBackendStateChanged()
 {
     if (!_current) return;
 
-    auto old = _state;
+    CoreState old = _state;
     switch (_current->state()) {
     case Backend::PlayState::Playing:
         _state = CoreState::Playing;
-
+        if (_playlist->count() > 0) {
+            m_bAudio = currFileIsAudio();
+        }
         //playing . emit thumbnail progress mode signal with setting file
-        emit siginitthumbnailseting();
+        if (old == CoreState::Idle)
+            emit siginitthumbnailseting();
         break;
     case Backend::PlayState::Paused:
         _state = CoreState::Paused;
@@ -519,6 +502,11 @@ void PlayerEngine::changehwaccelMode(Backend::hwaccelMode hwaccelMode)
     return _current->changehwaccelMode(hwaccelMode);
 }
 
+Backend *PlayerEngine::getMpvProxy()
+{
+    return _current;
+}
+
 void PlayerEngine::toggleMute()
 {
     if (!_current) return;
@@ -544,29 +532,23 @@ void PlayerEngine::savePreviousMovieState()
 
 void PlayerEngine::paintEvent(QPaintEvent *e)
 {
-    bool bIsMusic = false;
     QRect rect = this->rect();
     QPainter p(this);
 
-    if (_playlist->count() > 0 && _state != Idle) {
-        bIsMusic = isAudioFile(_playlist->currentInfo().mi.title);
-    }
-
-    if (!CompositingManager::get().composited()) {
-        if (_state != Idle && bIsMusic) {
+    if (!CompositingManager::get().composited() || utils::check_wayland_env()) {  // wayland下不会进入mainwindow的paintevent函数导致图标未绘制
+        if (_state != Idle && m_bAudio) {
             p.fillRect(rect, QBrush(QColor(0, 0, 0)));
         } else {
-            QImage icon = utils::LoadHiDPIImage(":/resources/icons/light/init-splash.svg");
+            QImage icon = QIcon::fromTheme("deepin-movie").pixmap(130, 130).toImage();;
             QPixmap pix = QPixmap::fromImage(icon);
-            int x = this->rect().center().x() - pix.width() / 2;
-            int y = this->rect().center().y() - pix.height() / 2;
+            QPointF pos = rect.center() - QPoint(pix.width() / 2, pix.height() / 2) / devicePixelRatioF();
 
             if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
                 p.fillRect(rect, QBrush(QColor(255, 255, 255)));
-                p.drawPixmap(x, y, pix);
+                p.drawPixmap(pos, pix);
             } else {
                 p.fillRect(rect, QBrush(QColor(0, 0, 0)));
-                p.drawPixmap(x, y, pix);
+                p.drawPixmap(pos, pix);
             }
         }
     }
@@ -592,6 +574,18 @@ void PlayerEngine::requestPlay(int id)
     } else {
         // TODO: delete and try next backend?
     }
+
+    QJsonObject obj{
+        {"tid", EventLogUtils::StartPlaying},
+        {"version", VERSION},
+        {"successful", item.url.isLocalFile() ? "true" : ""},
+        {"type", currFileIsAudio() ? "audio" : "video"},
+        {"origin", item.url.isLocalFile() ? "local" : "http"},
+        {"encapsulation_format", item.mi.fileType},
+        {"coding_format",  utils::videoIndex2str(item.mi.vCodecID)}
+    };
+
+    EventLogUtils::get().writeLogs(obj);
 }
 
 void PlayerEngine::savePlaybackPosition()
@@ -671,7 +665,7 @@ void PlayerEngine::onPlaylistAsyncAppendFinished(const QList<PlayItemInfo> &pil)
 void PlayerEngine::playByName(const QUrl &url)
 {
     savePreviousMovieState();
-    auto id = _playlist->indexOf(url);
+    int id = _playlist->indexOf(url);
     qInfo() << __func__ << url << "id:" << id;
     if (id >= 0) {
         _playlist->changeCurrent(id);
@@ -765,105 +759,116 @@ void PlayerEngine::setDVDDevice(const QString &path)
     _current->setDVDDevice(path);
 }
 
-/*void PlayerEngine::firstInit()
-{
-    _current->firstInit();
-    addSubSearchPath(OnlineSubtitle::get().storeLocation());
-}*/
-
 bool PlayerEngine::addPlayFile(const QUrl &url)
 {
-    qInfo() << __func__;
-    if (isPlayableFile(url)) {
-        if (url.isLocalFile())
-            _playlist->appendAsync({url});
-        else
-            _playlist->append(url);
-        return true;
-    }
-    return false;
-}
+    QUrl realUrl;
 
-QList<QUrl> PlayerEngine::collectPlayDir(const QDir &dir)
-{
-    QList<QUrl> urls;
-    QString strtp;
+    realUrl = FileFilter::instance()->fileTransfer(url.toString());
+    if (!isPlayableFile(realUrl))
+        return false;
 
-    //取消递归  by thx
-    QDirIterator di(dir, QDirIterator::NoIteratorFlags);
-    while (di.hasNext()) {
-        di.next();
-        if (di.fileInfo().isFile() && isPlayableFile(di.fileName())) {
-            strtp = di.filePath();
-            while (QFileInfo(strtp).isSymLink()) {
-                /*****************************
-                 * use oringnal path to replace link path
-                 * ***************************/
-                strtp = QFileInfo(strtp).symLinkTarget();
-            }
-            urls.append(QUrl::fromLocalFile(strtp));
-        }
-    }
-
-    return urls;
+    _playlist->append({realUrl});
+    return true;
 }
 
 QList<QUrl> PlayerEngine::addPlayDir(const QDir &dir)
 {
-    auto valids = collectPlayDir(dir);
+    QList<QUrl> valids = FileFilter::instance()->filterDir(dir);
+
+    struct {
+        bool operator()(const QUrl& fi1, const QUrl& fi2) const {
+            static QRegExp rd("\\d+");
+            int pos = 0;
+            QString fileName1 = QFileInfo(fi1.toLocalFile()).fileName();
+            QString fileName2 = QFileInfo(fi2.toLocalFile()).fileName();
+            while ((pos = rd.indexIn(fileName1, pos)) != -1) {
+                auto inc = rd.matchedLength();
+                auto id1 = fileName1.midRef(pos, inc);
+
+                auto pos2 = rd.indexIn(fileName2, pos);
+                if (pos == pos2) {
+                    auto id2 = fileName2.midRef(pos, rd.matchedLength());
+                    //qInfo() << "id compare " << id1 << id2;
+                    if (id1 != id2) {
+                        bool ok1, ok2;
+                        bool v = id1.toInt(&ok1) < id2.toInt(&ok2);
+                        if (ok1 && ok2) return v;
+                        return id1.localeAwareCompare(id2) < 0;
+                    }
+                }
+
+                pos += inc;
+            }
+            return fileName1.localeAwareCompare(fileName2) < 0;
+        }
+    } SortByDigits;
+
+    std::sort(valids.begin(), valids.end(), SortByDigits);
+    valids = addPlayFiles(valids);
     _playlist->appendAsync(valids);
+
     return valids;
 }
 
-
 QList<QUrl> PlayerEngine::addPlayFiles(const QList<QUrl> &urls)
 {
     qInfo() << __func__;
-    QList<QUrl> valids = collectPlayFiles(urls);
-    for (auto &url : valids) {
-        QString strtp = url.toLocalFile();
-        while (QFileInfo(strtp).isSymLink()) {
-            /*****************************
-             * use oringnal path to replace link path
-             * ***************************/
-            strtp = QFileInfo(strtp).symLinkTarget();
-        }
-        url = QUrl::fromLocalFile(strtp);
+    QList<QUrl> valids;
+
+    for (QUrl url : urls) {
+        if (m_stopRunningThread)
+            break;
+        if (isPlayableFile(url))
+            valids << url;
     }
+
     _playlist->appendAsync(valids);
+
     return valids;
 }
 
-QList<QUrl> PlayerEngine::collectPlayFiles(const QList<QUrl> &urls)
+QList<QUrl> PlayerEngine::addPlayFiles(const QList<QString> &lstFile)
 {
-    qInfo() << urls;
-    //NOTE: take care of loop, we don't recursive, it seems safe now
+    qInfo() << __func__;
     QList<QUrl> valids;
-    for (const auto &url : urls) {
-        if (url.isLocalFile()) {
-            QFileInfo fi(url.toLocalFile());
-            if (!fi.exists()) {
-                qInfo() << url << "don't exist";
-                continue;
-            }
+    QUrl realUrl;
 
-            if (fi.isDir()) {
-                auto subs = collectPlayDir(fi.absoluteFilePath());
-                valids += subs;
-                valids += url;
-                continue;
-            }
-
-            if (!url.isValid() || !isPlayableFile(url)) {
-                qInfo() << url << "not valid or playable";
-                continue;
-            }
-
-            valids.append(url);
-        }
+    for (QString strFile : lstFile) {
+          realUrl = FileFilter::instance()->fileTransfer(strFile);
+          if (QFileInfo(realUrl.path()).isDir()) {
+              if (realUrl.isLocalFile())          // 保证不是网络路径
+                  valids << FileFilter::instance()->filterDir(QDir(realUrl.path()));
+          } else {
+              valids << realUrl;
+          }
     }
 
-    return valids;
+    return addPlayFiles(valids);
+}
+
+void PlayerEngine::addPlayFs(const QList<QString> &lstFile)
+{
+    qInfo() << __func__;
+    QList<QUrl> valids;
+    QUrl realUrl;
+
+    for (QString strFile : lstFile) {
+          realUrl = FileFilter::instance()->fileTransfer(strFile);
+          if (QFileInfo(realUrl.path()).isDir()) {
+              if (realUrl.isLocalFile())          // 保证不是网络路径
+                  valids << FileFilter::instance()->filterDir(QDir(realUrl.path()));
+          } else {
+              valids << realUrl;
+          }
+    }
+
+    if (valids.isEmpty()) {
+        blockSignals(false);
+        return;
+    }
+    QList<QUrl> addFiles = addPlayFiles(valids);
+    blockSignals(false);
+    emit finishedAddFiles(addFiles);
 }
 
 qint64 PlayerEngine::duration() const
@@ -933,7 +938,7 @@ void PlayerEngine::resizeEvent(QResizeEvent *)
 
         QPainter p(&shape);
         QPainterPath pp;
-        pp.addRoundedRect(rect(), RADIUS, RADIUS);
+        pp.addRect(rect());
         p.fillPath(pp, QBrush(Qt::white));
         p.end();
 
@@ -945,8 +950,6 @@ void PlayerEngine::resizeEvent(QResizeEvent *)
 
 }
 
-
-
 void PlayerEngine::setBackendProperty(const QString &name, const QVariant &val)
 {
     if (_current) {
@@ -962,11 +965,34 @@ QVariant PlayerEngine::getBackendProperty(const QString &name)
     return QVariant();
 }
 
-/*void PlayerEngine::setVideoZoom(float val)
+void PlayerEngine::toggleRoundedClip(bool roundClip)
 {
-    if (_current) {
-        _current->setProperty("video-zoom", val);
+    MpvProxy* pMpvProxy = nullptr;
+
+    pMpvProxy = dynamic_cast<MpvProxy *>(_current);
+    if(!pMpvProxy) {
+        dynamic_cast<QtPlayerProxy *>(_current)->updateRoundClip(roundClip);
+    } else {
+        pMpvProxy->updateRoundClip(roundClip);
     }
-}*/
+}
+
+bool PlayerEngine::currFileIsAudio()
+{
+    bool bAudio = false;
+    PlayItemInfo pif;
+
+    if (_playlist->count() > 0) {
+        pif = _playlist->currentInfo();
+    }
+
+    if (CompositingManager::isMpvExists()) {
+        bAudio = pif.thumbnail.isNull() && pif.url.isLocalFile();
+    } else {
+        bAudio = isAudioFile(pif.url.toString());
+    }
+
+    return bAudio;
+}
 
 } // end of namespace dmr
