@@ -41,6 +41,9 @@
 
 #include <libffmpegthumbnailer/videothumbnailerc.h>
 
+#define THUMBNAIL_SIZE 500
+#define SEEK_TIME "00:00:01"
+
 typedef video_thumbnailer *(*mvideo_thumbnailer)();
 typedef void (*mvideo_thumbnailer_destroy)(video_thumbnailer *thumbnailer);
 /* create image_data structure */
@@ -68,7 +71,6 @@ struct MovieInfo {
     qint64 duration;
     int width = -1;
     int height = -1;
-
     //3.4添加视频信息
     //视频流信息
     int vCodecID;
@@ -81,6 +83,26 @@ struct MovieInfo {
     int aDigit;
     int channels;
     int sampling;
+#ifdef _MOVIE_USE_
+    QString strFmtName; // 文件封装名
+#endif
+    MovieInfo() {
+        valid = false;
+        raw_rotate = -1;
+        fileSize = -1;
+        duration = -1;
+        width = -1;
+        height = -1;
+        vCodecID = -1;
+        aCodeRate = -1;
+        fps = -1;
+        proportion = -1.0;
+        aCodeID = -1;
+        aCodeRate = -1;
+        aDigit = -1;
+        channels = -1;
+        sampling = -1;
+    }
 
     static struct MovieInfo parseFromFile(const QFileInfo &fi, bool *ok = nullptr);
     QString durationStr() const
@@ -118,6 +140,20 @@ struct MovieInfo {
         }
         return QString(QT_TR_NOOP("%1")).arg(fileSize);
     }
+    /**
+     * @brief 判断是否是H.264裸流，因为没有时长等信息所以需要对此类型单独判断
+     * @return 是否是裸流
+     */
+    bool isRawFormat() const
+    {
+        bool bFlag = false;
+#ifdef _MOVIE_USE_
+        if(strFmtName.contains("raw",Qt::CaseInsensitive))
+            bFlag = true;
+#endif
+
+        return bFlag;
+    }
 };
 
 
@@ -164,7 +200,14 @@ public:
 
     qint64 getUrlFileTotalSize(QUrl url, int tryTimes) const;
 
+    /**
+     * @brief clear 清空播放列表
+     */
     void clear();
+    /**
+     * @brief remove 移除播放列表中的选定项
+     * @param pos 传入的删除项
+     */
     void remove(int pos);
     void append(const QUrl &);
 
@@ -187,6 +230,7 @@ public:
     int current() const;
     const PlayItemInfo &currentInfo() const;
     PlayItemInfo &currentInfo();
+    int size() const;
     int indexOf(const QUrl &url);
 
     void switchPosition(int p1, int p2);
@@ -208,7 +252,11 @@ public:
      */
     bool getThumanbilRunning();
 
-    bool isMediaFile(QString sFileName);    //判断一个文件是否是多媒体文件
+    //获取视频信息
+    MovieInfo getMovieInfo(const QUrl &url, bool *is);
+
+    //获取视频首帧图片
+    QImage getMovieCover(const QUrl &url);
 
 public slots:
     void changeCurrent(int);
@@ -239,6 +287,7 @@ private:
     void initFFmpeg();
     bool getMusicPix(const QFileInfo &fi, QPixmap &rImg);
     struct MovieInfo parseFromFile(const QFileInfo &fi, bool *ok = nullptr);
+    struct MovieInfo parseFromFileByQt(const QFileInfo &fi, bool *ok = nullptr);
     QString libPath(const QString &strlib);
     // when app starts, and the first time to load playlist
     bool _firstLoad {true};
@@ -255,7 +304,6 @@ private:
 
     QList<AppendJob> _pendingJob; // async job
     QSet<QString> _urlsInJob;  // url list
-    QFutureWatcher<PlayItemInfo> *_jobWatcher {nullptr};
 
     QQueue<UrlList> _pendingAppendReq;
 
@@ -280,13 +328,12 @@ private:
     bool m_brunning;
     QList<QUrl> m_tempList;
     QList<QUrl> m_loadFile;
-    bool m_isLoadRunning {false};
     bool m_initFFmpeg {false};
+    bool m_bInitThumb {false};
 
     void reshuffle();
     void appendSingle(const QUrl &);
     void tryPlayCurrent(bool next);
-
 };
 
 
@@ -318,15 +365,12 @@ public:
 //        m_model = model;
 //        m_urls = urls;
         m_mutex = new QMutex;
-        m_itemMutex = new QMutex;
     };
     ~GetThumanbil()
     {
         m_stop = true;
         delete m_mutex;
         m_mutex = nullptr;
-        delete m_itemMutex;
-        m_itemMutex = nullptr;
     };
     //QList<PlayItemInfo> getInfoList() {return m_itemInfo;}
     void stop()
@@ -341,10 +385,10 @@ public:
     };
     void clearItem()
     {
-        m_itemMutex->lock();
+        m_mutex->lock();
         //m_itemInfo.clear();
         m_urls.clear();
-        m_itemMutex->unlock();
+        m_mutex->unlock();
     };
 
     void run()
@@ -354,12 +398,10 @@ public:
         m_mutex->unlock();
         foreach (QUrl url, urls) {
             QFileInfo info(url.path());
-            m_itemMutex->lock();
             //m_itemInfo.append();
             emit updateItem(m_model->calculatePlayInfo(url, info, false));
-            m_itemMutex->unlock();
-            m_isFinished = true;
-            if (m_stop) break;
+            if (m_stop)
+                break;
         }
     }
 
@@ -370,12 +412,9 @@ private:
     QList<QUrl> m_urls;
     //QList<PlayItemInfo> m_itemInfo;
     QMutex *m_mutex;
-    QMutex *m_itemMutex;
-    bool m_isFinished {true};
     bool m_stop {false};
 };
 
-
 }
 
 #endif /* ifndef _DMR_PLAYLIST_MODEL_H */
