@@ -57,16 +57,8 @@ void ShowInFileManager(const QString &path)
     qInfo() << __func__ << url.toString();
 
     // Try dde-file-manager
-    QProcess *fp = new QProcess();
-    QObject::connect(fp, SIGNAL(finished(int)), fp, SLOT(deleteLater()));
-#ifndef USE_TEST
-    fp->start("dde-file-manager", QStringList(url.toString()));
-#else
-    fp->start("wrong-name-for-test", QStringList(url.toString()));
-#endif
-    fp->waitForStarted(3000);
 
-    if (fp->error() == QProcess::FailedToStart) {
+    if (url.isLocalFile()) {
         // Start dde-file-manager failed, try nautilus
         QDBusInterface iface("org.freedesktop.FileManager1",
                              "/org/freedesktop/FileManager1",
@@ -85,7 +77,6 @@ void ShowInFileManager(const QString &path)
             qInfo() << "desktopService::openUrl";
             QDesktopServices::openUrl(QUrl::fromLocalFile(QFileInfo(path).dir().absolutePath()));
         }
-        fp->deleteLater();
     }
 }
 
@@ -125,7 +116,7 @@ static int stringDistance(const QString &s1, const QString &s2)
 
 bool IsNamesSimilar(const QString &s1, const QString &s2)
 {
-    auto dist = stringDistance(s1, s2);
+    int dist = stringDistance(s1, s2);
     return (dist >= 0 && dist <= 4); //TODO: check ext.
 }
 
@@ -145,13 +136,6 @@ QFileInfoList FindSimilarFiles(const QFileInfo &fi)
         }
 
     }
-
-    //struct {
-    //bool operator()(const QFileInfo& fi1, const QFileInfo& fi2) const {
-    //return CompareNames(fi1.fileName(), fi2.fileName());
-    //}
-    //} SortByDigits;
-    //std::sort(fil.begin(), fil.end(), SortByDigits);
     return fil;
 }
 
@@ -282,6 +266,8 @@ QPixmap MakeRoundedPixmap(QPixmap pm, qreal rx, qreal ry, int rotation)
 
 QPixmap MakeRoundedPixmap(QSize sz, QPixmap pm, qreal rx, qreal ry, qint64 time)
 {
+    int nX = 0;
+    int nY = 0;
     auto dpr = pm.devicePixelRatio();
     QPixmap dest(sz);
     dest.setDevicePixelRatio(dpr);
@@ -299,7 +285,9 @@ QPixmap MakeRoundedPixmap(QSize sz, QPixmap pm, qreal rx, qreal ry, qint64 time)
     auto r = scaled_rect.marginsRemoved({1, 1, 1, 1});
     path.addRoundedRect(r, rx, ry);
     p.setClipPath(path);
-    p.drawPixmap(1, 1, pm);
+    nX = (sz.width() - pm.width()) / 2;
+    nY = (sz.height() - pm.height()) / 2;
+    p.drawPixmap(nX, nY, pm);
 
 
     p.setCompositionMode(QPainter::CompositionMode_SourceOver);
