@@ -47,32 +47,41 @@
 #include "options.h"
 #include "dmr_settings.h"
 #include "mainwindow.h"
-#include "dbus_adpator.h"
+#include "platform/platform_mainwindow.h"
+#include "platform/platform_dbus_adpator.h"
 #include "compositing_manager.h"
+#include "dbus_adpator.h"
 #include "utils.h"
 #include "movie_configuration.h"
 #include "vendor/movieapp.h"
 #include "vendor/presenter.h"
 #include <QSettings>
 
+#include <DStandardPaths>
 
 #include <stdio.h>
 #include <unistd.h>
 #include <fcntl.h>
+#include <va/va_x11.h>
 
 #include "accessibility/acobjectlist.h"
 DWIDGET_USE_NAMESPACE
 
 bool runSingleInstance()
 {
+    std::string path;
     QString userName = QDir::homePath().section("/", -1, -1);
-    std::string path = ("/home/" + userName + "/.cache/deepin/deepin-movie/").toStdString();
+    if (userName == "root") {
+        path = "/tmp/deepin-movie";
+    } else {
+        path = DStandardPaths::writableLocation(QStandardPaths::AppConfigLocation).toStdString();
+    }
     QDir tdir(path.c_str());
     if (!tdir.exists()) {
         tdir.mkpath(path.c_str());
     }
 
-    path += "single";
+    path += "/single";
     int fd = open(path.c_str(), O_WRONLY | O_CREAT, 0644);
     int flock = lockf(fd, F_TLOCK, 0);
 
@@ -87,19 +96,49 @@ bool runSingleInstance()
     return true;
 }
 
+#ifdef __x86_64__
+//进程检测是否支持硬解
+void checkIsCanHwdec(int argc, char *argv[])
+{
+    QApplication a(argc, argv);
+    Display *x11=QX11Info::display();
+    VADisplay *display = (VADisplay *)vaGetDisplay(x11);
+    int major, minor;
+    int status = 0;
+    try {
+        status = vaInitialize(display, &major, &minor);
+    }
+    catch (...) {
+        status = -1;
+    }
+    exit(status);
+}
+#endif
 
 int main(int argc, char *argv[])
 {
-#ifdef __aarch64__
+    //for qt5platform-plugins load DPlatformIntegration or DPlatformIntegrationParent
+    if (!QString(qgetenv("XDG_CURRENT_DESKTOP")).toLower().startsWith("deepin")){
+        setenv("XDG_CURRENT_DESKTOP", "Deepin", 1);
+    }
+
+#ifdef __x86_64__
+    if(argc==2 && strcmp(argv[1],"hwdec") == 0) {
+        checkIsCanHwdec(argc, argv);
+    }
+#endif
+//#ifdef __aarch64__ //wayland平台支持影院播放
     if (dmr::utils::first_check_wayland_env()) {
         qputenv("QT_WAYLAND_SHELL_INTEGRATION", "kwayland-shell");
         //qputenv("_d_disableDBusFileDialog", "true");
         setenv("PULSE_PROP_media.role", "video", 1);
+#ifndef __x86_64__
         QSurfaceFormat format;
         format.setRenderableType(QSurfaceFormat::OpenGLES);
         format.setDefaultFormat(format);
-    }
 #endif
+    }
+//#endif
 #ifdef __mips__
     if (CompositingManager::get().composited()) {
         CompositingManager::detectOpenGLEarly();
@@ -109,6 +148,10 @@ int main(int argc, char *argv[])
 #if defined(STATIC_LIB)
     DWIDGET_INIT_RESOURCE();
 #endif
+    QFileInfo fi("/dev/mwv206_0");
+    if (fi.exists() && !CompositingManager::isMpvExists()) {
+        qputenv("QT_XCB_GL_INTEGRATION", "xcb_egl");
+    }
     /**
       *This function dtk is obsolete and has no
       * impact after testing on x86 platform.
@@ -143,10 +186,11 @@ int main(int argc, char *argv[])
     app->setOrganizationName("deepin");
     app->setApplicationName("deepin-movie");
     app->setApplicationVersion(DMR_VERSION);
-    app->setProductIcon(utils::LoadHiDPIPixmap(":/resources/icons/logo-big.svg"));
-    app->setWindowIcon(QIcon(":/resources/icons/logo-big.svg"));
+    app->setProductIcon(QIcon::fromTheme("deepin-movie"));
+    app->setWindowIcon(QIcon::fromTheme("deepin-movie"));
     QString acknowledgementLink = "https://www.deepin.org/acknowledgments/deepin-movie";
     app->setApplicationAcknowledgementPage(acknowledgementLink);
+    app->setApplicationVersion(DApplication::buildVersion(VERSION));
 
     //save theme
     DApplicationSettings saveTheme;
@@ -203,34 +247,62 @@ int main(int argc, char *argv[])
     app->setAttribute(Qt::AA_DontCreateNativeWidgetSiblings, true);
 
 //    app.setApplicationVersion(DApplication::buildVersion("20190830"));
-    app->setApplicationVersion(DApplication::buildVersion(VERSION));
     MovieConfiguration::get().init();
 
     QRegExp url_re("\\w+://");
 
-    dmr::MainWindow mw;
-    Presenter *presenter = new Presenter(&mw);
-//    mw.setMinimumSize(QSize(1070, 680));
-    mw.setPresenter(presenter);
-    if (CompositingManager::isPadSystem()) {
-        ///平板模式下全屏显示
-        mw.showMaximized();
+    if (CompositingManager::get().composited()) {
+        dmr::MainWindow mw;
+        Presenter *presenter = new Presenter(&mw);
+    //    mw.setMinimumSize(QSize(1070, 680));
+        mw.setPresenter(presenter);
+        if (CompositingManager::isPadSystem()) {
+            ///平板模式下全屏显示
+            mw.showMaximized();
+        } else {
+            mw.resize(850, 600);
+            Dtk::Widget::moveToCenter(&mw);
+            mw.show();
+        }
+
+        mw.setOpenFiles(toOpenFiles);
+
+        if (!QDBusConnection::sessionBus().isConnected()) {
+            qWarning() << "dbus disconnected";
+        }
+
+        ApplicationAdaptor adaptor(&mw);
+        QDBusConnection::sessionBus().registerService("com.deepin.movie");
+        QDBusConnection::sessionBus().registerObject("/", &mw);
+
+        return app->exec();
     } else {
-        mw.resize(850, 600);
-        utils::MoveToCenter(&mw);
-        mw.show();
+        dmr::Platform_MainWindow platform_mw;
+        Presenter *presenter = new Presenter(&platform_mw);
+    //    mw.setMinimumSize(QSize(1070, 680));
+        platform_mw.setPresenter(presenter);
+        if (CompositingManager::isPadSystem()) {
+            ///平板模式下全屏显示
+            platform_mw.showMaximized();
+        } else {
+            platform_mw.resize(850, 600);
+            Dtk::Widget::moveToCenter(&platform_mw);
+            platform_mw.show();
+        }
+
+        platform_mw.setOpenFiles(toOpenFiles);
+
+        if (!QDBusConnection::sessionBus().isConnected()) {
+            qWarning() << "dbus disconnected";
+        }
+
+        Platform_ApplicationAdaptor adaptor(&platform_mw);
+        QDBusConnection::sessionBus().registerService("com.deepin.movie");
+        QDBusConnection::sessionBus().registerObject("/", &platform_mw);
+
+        return app->exec();
     }
 
-    mw.setOpenFiles(toOpenFiles);
-
-    if (!QDBusConnection::sessionBus().isConnected()) {
-        qWarning() << "dbus disconnected";
-    }
-
-    ApplicationAdaptor adaptor(&mw);
-    QDBusConnection::sessionBus().registerService("com.deepin.movie");
-    QDBusConnection::sessionBus().registerObject("/", &mw);
-
 //    if (!toOpenFiles.isEmpty()) {
 //        if (toOpenFiles.size() == 1) {
 //            mw.play(toOpenFiles[0]);
@@ -238,7 +310,5 @@ int main(int argc, char *argv[])
 //            mw.playList(toOpenFiles);
 //        }
 //    }
-    return app->exec();
-
 }
 
