@@ -52,40 +52,6 @@
 #define POPUP_DURATION 350
 
 namespace dmr {
-
-/*QString splitText(const QString &text, int width,
-                  QTextOption::WrapMode wordWrap, const QFont &font, int lineHeight)
-{
-    int height = 0;
-
-    QTextLayout textLayout(text);
-    QString str;
-
-    textLayout.setFont(font);
-    const_cast<QTextOption *>(&textLayout.textOption())->setWrapMode(wordWrap);
-
-    textLayout.beginLayout();
-    QTextLine line = textLayout.createLine();
-    while (line.isValid()) {
-        height += lineHeight;
-
-        line.setLineWidth(width);
-        const QString &tmp_str = text.mid(line.textStart(), line.textLength());
-        if (tmp_str.indexOf('\n'))
-            height += lineHeight;
-
-        str += tmp_str;
-        line = textLayout.createLine();
-
-        if (line.isValid())
-            str.append("\n");
-    }
-
-    textLayout.endLayout();
-
-    return str;
-}*/
-
 class PlayItemTooltipHandler: public QObject
 {
 public:
@@ -97,20 +63,18 @@ protected:
         switch (event->type()) {
         case QEvent::ToolTip: {
             QHelpEvent *he = static_cast<QHelpEvent *>(event);
-            auto tip = obj->property("HintWidget").value<Tip *>();
-            auto item = tip->property("for").value<QWidget *>();
-            auto lb = tip->findChild<DLabel *>("TipText");
+            Tip *tip = obj->property("HintWidget").value<Tip *>();
+            QWidget *item = tip->property("for").value<QWidget *>();
+            DLabel *lb = tip->findChild<DLabel *>("TipText");
+            if (tip->isVisible())
+                return true; //tip弹出后不再更新位置
             lb->setAlignment(Qt::AlignLeft);
-
-//            auto msg = splitText(item->toolTip(), 200, QTextOption::WordWrap, lb->font(),
-//                                 lb->fontMetrics().height());
-//            lb->setText(msg);
             tip->update();
             tip->show();
             tip->adjustSize();
             tip->raise();
-            auto pos = he->globalPos() + QPoint{0, 10};
-            auto dw = qApp->desktop()->availableGeometry(item).width();
+            QPoint pos = he->globalPos() + QPoint{0, 10};
+            int dw = qApp->desktop()->availableGeometry(item).width();
             if (pos.x() + tip->width() > dw) {
                 pos.rx() = dw - tip->width();
             }
@@ -140,16 +104,16 @@ enum ItemState {
 class PlayItemWidget: public QFrame
 {
     Q_OBJECT
-//    Q_PROPERTY(QString bg READ getBg WRITE setBg DESIGNABLE true)
 public:
     friend class PlaylistWidget;
 
     PlayItemWidget(const PlayItemInfo &pif, QListWidget *list = nullptr, int index = 0, PlaylistWidget *parent = nullptr)
         : QFrame(), _pif {pif}, _listWidget {list}, _playlist{parent}
     {
-//        DThemeManager::instance()->registerWidget(this, QStringList() << "PlayItemThumb");
+        _thumb = nullptr;
+        m_pSvgWidget = nullptr;
         setProperty("PlayItemThumb", "true");
-        setState(ItemState::Normal);
+        //setState(ItemState::Normal);
         setFrameShape(QFrame::NoFrame);
         this->setObjectName(PLAYITEM_WIDGET);
         auto kd = "local";
@@ -178,12 +142,26 @@ public:
         _index->setFixedWidth(22);
         l->addWidget(_index);
 
-        _thumb = new ListPic(_pif.thumbnail.scaled(QSize(42, 24)), this);
-        if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
-            _thumb->setPic(_pif.thumbnail_dark);
-        };
-//        _thumb->setPixmap(_pif.thumbnail.scaled(QSize(42,24)));
-        l->addWidget(_thumb);
+        if (_pif.thumbnail.isNull() && _pif.thumbnail_dark.isNull()) {
+            if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+                m_pSvgWidget = new QSvgWidget(QString(":/resources/icons/music-dark.svg"), this);
+            } else {
+                m_pSvgWidget = new QSvgWidget(QString(":/resources/icons/music-light.svg"), this);
+            }
+            m_pSvgWidget->setFixedSize(42, 24);
+        } else {
+            if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+                _thumb = new ListPic(_pif.thumbnail_dark.scaled(QSize(42, 24)), this);
+            } else {
+                _thumb = new ListPic(_pif.thumbnail.scaled(QSize(42, 24)), this);
+            }
+        }
+
+        if (_thumb) {
+            l->addWidget(_thumb);
+        } else {
+            l->addWidget(m_pSvgWidget);
+        }
         QObject::connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &PlayItemWidget::slotThemeTypeChanged);
 
 
@@ -196,21 +174,13 @@ public:
 
         _name = new DLabel(this);
         _name->setProperty("Name", true);
-//        _name->setReadOnly(true);
-//        _name->setAcceptRichText(false);
-//        _name->setWordWrapMode(QTextOption::NoWrap);
-//        _name->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-//        _name->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
         _name->setFrameShape(QFrame::NoFrame);
         _name->setTextInteractionFlags(Qt::NoTextInteraction);
         _name->setFixedWidth(width() - 180);
-//        _name->setStyleSheet("background: red;");
         _name->installEventFilter(this);
-//        _name->viewport()->setAutoFillBackground(false);
         _name->setAutoFillBackground(false);
 
         vl->addWidget(_name);
-//        vl->addStretch(1);
 
         _time = new DLabel(this);
         DFontSizeManager::instance()->bind(_time, DFontSizeManager::T9);
@@ -220,14 +190,10 @@ public:
             setState(ItemState::Invalid);
             _time->setText(tr("The file does not exist"));
         }
-//        vl->addWidget(_time);
         vl->addStretch();
         l->addWidget(_time);
         l->addSpacing(10);
 
-//        setBg(QString(":/resources/icons/%1/normal/film-bg.svg").arg(qApp->theme()));
-
-        //_closeBtn = new FloatingButton(this);
         _closeBtn = new DFloatingButton(DStyle::SP_CloseButton, this);
         _closeBtn->setFocusPolicy(Qt::NoFocus);
         _closeBtn->setObjectName(PLAYITEN_CLOSE_BUTTON);
@@ -236,8 +202,6 @@ public:
         _closeBtn->setFixedSize(25, 25);
         _closeBtn->hide();
         connect(_closeBtn, &DFloatingButton::clicked, this, &PlayItemWidget::closeButtonClicked);
-        //connect(_closeBtn, &FloatingButton::clicked, this, &PlayItemWidget::closeButtonClicked);
-        //connect(_closeBtn, &FloatingButton::mouseHover, this, &PlayItemWidget::closeBtnStates);
 
         setToolTip(_pif.mi.title);
         auto th = new PlayItemTooltipHandler(this);
@@ -250,9 +214,28 @@ public:
         t->layout()->setContentsMargins(5, 10, 5, 10);
         t->hide();
         setProperty("HintWidget", QVariant::fromValue<QWidget *>(t));
-        installEventFilter(th);
+        if (!utils::check_wayland_env())
+            installEventFilter(th);
         connect(_playlist, &PlaylistWidget::sizeChange, this, &PlayItemWidget::slotSizeChange);
 
+        m_opacityEffect = new QGraphicsOpacityEffect;
+        _time->setGraphicsEffect(m_opacityEffect);
+        m_opacityEffect_1 = new QGraphicsOpacityEffect;
+        _index->setGraphicsEffect(m_opacityEffect_1);
+        setState(ItemState::Normal);
+    }
+    
+    ~PlayItemWidget() override
+    {
+        if (m_pSvgWidget) {
+            delete  m_pSvgWidget;
+            m_pSvgWidget = nullptr;
+        }
+
+        if (_thumb) {
+            delete _thumb;
+            _thumb = nullptr;
+        }
     }
 
     void updateInfo(const PlayItemInfo &pif)
@@ -266,14 +249,13 @@ public:
             setState(ItemState::Invalid);
             _time->setText(tr("The file does not exist"));
         }
-//        setStyleSheet(styleSheet());
         update();
     }
 
     void setState(ItemState is)
     {
         setProperty("ItemState", is);
-        update();
+        updateForeground();
     }
 
     ItemState state() const
@@ -285,63 +267,11 @@ public:
         _index->setText(QString::number(index + 1));
     }
 
-    ///not used functions,comment out it temporarily
-    /*QString getBg() const
-    {
-        return _bg;
-    }
-    void setBg(const QString &s)
-    {
-        _bg = s;
-
-        auto dpr = qApp->devicePixelRatio();
-
-        QPixmap pm = QPixmap::fromImage(utils::LoadHiDPIImage(s));
-
-        QPixmap dest(pm.size());
-        dest.setDevicePixelRatio(dpr);
-        dest.fill(Qt::transparent);
-        QPainter p(&dest);
-
-        if (state() == ItemState::Invalid) {
-            p.setOpacity(0.5);
-        }
-
-        // thumb size
-        QSize sz(22, 40);
-        sz *= dpr;
-
-        p.drawPixmap(0, 0, pm);
-
-        if (!_pif.thumbnail.isNull()) {
-            auto img = _pif.thumbnail.scaledToHeight(sz.height(), Qt::SmoothTransformation);
-            img.setDevicePixelRatio(dpr);
-
-            QPointF target_pos((pm.width() - sz.width()) / 2, (pm.height() - sz.height()) / 2);
-            target_pos /= dpr;
-
-            QRectF src_rect((img.width() - sz.width()) / 2, (img.height() - sz.height()) / 2,
-                            sz.width(), sz.height());
-            p.drawPixmap(target_pos, img, src_rect);
-
-        }
-
-        if (state() == ItemState::Playing) {
-            QPointF pos((pm.width() - _play.width()) / 2, (pm.height() - _play.height()) / 2);
-            pos /= dpr;
-            p.drawPixmap(pos, _play);
-        }
-        p.end();
-
-    //        _thumb->setPixmap(dest);
-    }*/
-
     void setHovered(bool v)
     {
         if (_hovered != v) {
             _hovered = v;
             setProperty("hovered", v);
-//            setStyleSheet(styleSheet());
         }
     }
 
@@ -371,7 +301,8 @@ public:
     void setBIsSelect(bool bIsSelect)
     {
         m_bIsSelect = bIsSelect;
-        update();
+
+        updateForeground();
     }
 
     void doDoubleClick()
@@ -384,7 +315,6 @@ public:
             setState(ItemState::Invalid);
             _time->setText(tr("The file does not exist"));
         }
-//        setStyleSheet(styleSheet());
         if (!_pif.url.isLocalFile() || _pif.info.exists()) {
             emit doubleClicked();
         }
@@ -395,17 +325,30 @@ signals:
     void doubleClicked();
 
 private slots:
-    /*void closeBtnStates(bool bHover)
-    {
-        setCurItemHovered(bHover);
-    }*/
     void slotThemeTypeChanged()
     {
+//        QPalette pa;
         if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
-            _thumb->setPic(_pif.thumbnail);
+            if (_thumb) {
+                _thumb->setPic(_pif.thumbnail);
+            } else {
+                m_pSvgWidget->load(QString(":/resources/icons/music-light.svg"));
+            }
+//            pa.setColor(QPalette::BrightText, Qt::black);
+//            _name->setPalette(pa);
+//            _index->setPalette(pa);
+            updateForeground();
         };
         if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
-            _thumb->setPic(_pif.thumbnail_dark);
+            if (_thumb) {
+                _thumb->setPic(_pif.thumbnail_dark);
+            } else {
+                m_pSvgWidget->load(QString(":/resources/icons/music-dark.svg"));
+            }
+//            pa.setColor(QPalette::BrightText, Qt::white);
+//            _name->setPalette(pa);
+//            _index->setPalette(pa);
+            updateForeground();
         }
     }
     void slotSizeChange()
@@ -417,12 +360,45 @@ protected:
     void updateClosePosition()
     {
         auto margin = 10;
-//        auto pl = dynamic_cast<QListWidget *>(parentWidget()->parentWidget());
-//        if (pl->verticalScrollBar()->isVisible())
-//            margin = 10;
         _closeBtn->move(width() - _closeBtn->width() - margin,
                         (height() - _closeBtn->height()) / 2);
     }
+    void updateForeground()
+    {
+        m_highlightColor = Dtk::Gui::DGuiApplicationHelper::instance()->applicationPalette().highlight().color();
+
+        if(m_bIsSelect) {
+            _name->setForegroundRole(DPalette::Text);
+            _index->setForegroundRole(DPalette::Text);
+
+            QPalette pa;
+            pa.setColor(QPalette::Text, Qt::white);
+            _name->setPalette(pa);
+            _index->setPalette(pa);
+            update();
+        } else {
+            if (state() == ItemState::Playing) {
+                _name->setForegroundRole(DPalette::Highlight);
+                _index->setForegroundRole(DPalette::Highlight);
+                _time->setForegroundRole(DPalette::Highlight);
+            } else {
+                _name->setForegroundRole(DPalette::BrightText);
+                _index->setForegroundRole(DPalette::BrightText);
+                _time->setForegroundRole(DPalette::BrightText);
+
+                QPalette pa;
+                if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+                    pa.setColor(QPalette::BrightText, Qt::black);
+                    _name->setPalette(pa);
+                    _index->setPalette(pa);
+                } else if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+                    pa.setColor(QPalette::BrightText, Qt::white);
+                    _name->setPalette(pa);
+                    _index->setPalette(pa);
+                }
+            }
+        }
+    }
     void leaveEvent(QEvent *e) override
     {
         _closeBtn->hide();
@@ -459,20 +435,10 @@ protected:
     bool event(QEvent *ee) override
     {
         if (ee->type() == QEvent::Resize) {
-//            int text_height = _name->document()->size().height();
             _name->setFixedHeight(36);
         }
 
         if (ee->type() == QEvent::Move) {
-//            _closeBtn->hide();
-//            if (isVisible()) {
-//                auto pos = _listWidget->mapFromGlobal(QCursor::pos());
-//                auto r = QRect(mapTo(_listWidget, QPoint()), size());
-//                if (r.contains(pos)) {
-//                    _closeBtn->show();
-//                    _closeBtn->raise();
-//                }
-//            }
         }
 
         return QFrame::event(ee);
@@ -481,26 +447,12 @@ protected:
     {
         _name->setText(utils::ElideText(_pif.mi.title, {width() - 242, 36}, QTextOption::NoWrap,
                                         _name->font(), Qt::ElideRight, 18, width() - 242));
-//        _name->viewport()->setCursor(Qt::ArrowCursor);
         _name->setCursor(Qt::ArrowCursor);
-//        _name->document()->setDocumentMargin(0.0);
-//        int text_height = _name->document()->size().height();
         _name->setFixedHeight(36);
     }
     void showEvent(QShowEvent *se) override
     {
         updateNameText();
-
-//        QTimer::singleShot(0, [=]() {
-//            auto pos = _listWidget->mapFromGlobal(QCursor::pos());
-//            auto r = QRect(mapTo(_listWidget, QPoint()), size());
-//            if (r.contains(pos)) {
-//                _closeBtn->show();
-//                _closeBtn->raise();
-//                updateClosePosition();
-//            }
-//        });
-
         QFrame::showEvent(se);
     }
     void mouseDoubleClickEvent(QMouseEvent *me) override
@@ -515,9 +467,8 @@ protected:
         painter.setRenderHint(QPainter::Antialiasing);
         QRectF bgRect;
         bgRect.setSize(size());
-        const DPalette pal = QGuiApplication::palette();//this->palette();
-        DStyleHelper styleHelper;
-        QStyleOption option;
+        const DPalette pal = QGuiApplication::palette();
+
         if (!(_index->text().toInt() % 2)) {
             QColor bgColor;
             if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType) {
@@ -530,6 +481,7 @@ protected:
             pp.addRoundedRect(bgRect, 8, 8);
             painter.fillPath(pp, bgColor);
         }
+
         if (_hovered) {
             DPalette pa = DApplicationHelper::instance()->palette(this);
             pa.setBrush(DPalette::Text, pa.color(DPalette::Highlight));
@@ -543,42 +495,6 @@ protected:
             painter.fillPath(pp, bgColor);
 
         }
-        if (state() == ItemState::Playing) {
-            QGraphicsOpacityEffect *opacityEffect = new QGraphicsOpacityEffect;
-            QGraphicsOpacityEffect *opacityEffect_1 = new QGraphicsOpacityEffect;
-            DPalette pa = DApplicationHelper::instance()->palette(this);
-
-            _time->setGraphicsEffect(opacityEffect);
-            _index->setGraphicsEffect(opacityEffect_1);
-            pa.setBrush(DPalette::Text, pa.color(DPalette::Highlight));
-            if (!m_bIsSelect) {
-                _name->setForegroundRole(DPalette::Highlight);
-                _index->setForegroundRole(DPalette::Highlight);
-                _time->setForegroundRole(DPalette::Highlight);
-            } else {
-                _name->setForegroundRole(DPalette::ToolTipText);
-                _index->setForegroundRole(DPalette::BrightText);
-                _time->setForegroundRole(DPalette::BrightText);
-            }
-            opacityEffect->setOpacity(1.0);
-        } else {
-            QGraphicsOpacityEffect *opacityEffect = new QGraphicsOpacityEffect;
-            QGraphicsOpacityEffect *opacityEffect_1 = new QGraphicsOpacityEffect;
-
-            _name->setForegroundRole(DPalette::ToolTipText);
-            _index->setForegroundRole(DPalette::BrightText);
-            _time->setForegroundRole(DPalette::BrightText);
-
-            _time->setGraphicsEffect(opacityEffect);
-            opacityEffect->setOpacity(0.5);
-
-            _index->setGraphicsEffect(opacityEffect_1);
-            if (m_bIsSelect) {
-                opacityEffect_1->setOpacity(1.0);
-            } else {
-                opacityEffect_1->setOpacity(0.5);
-            }
-        }
 
         if (!_pif.valid) {
             setState(ItemState::Invalid);
@@ -590,40 +506,13 @@ protected:
             _time->hide();
             _closeBtn->show();
             _closeBtn->raise();
-            QColor bgColor = Dtk::Gui::DGuiApplicationHelper::instance()->applicationPalette().highlight().color();
             QPainterPath pp;
             pp.addRoundedRect(bgRect, 8, 8);
-            painter.fillPath(pp, bgColor);
-
-            QPalette pe;
-            if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
-                pe.setColor(QPalette::ToolTipText, Qt::white);
-                _name->setPalette(pe);
-                pe.setColor(QPalette::BrightText, Qt::white);
-                _index->setPalette(pe);
-            } else if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
-                pe.setColor(QPalette::ToolTipText, Qt::white);
-                _name->setPalette(pe);
-                pe.setColor(QPalette::BrightText, Qt::white);
-                _index->setPalette(pe);
-            }
+            painter.fillPath(pp, m_highlightColor);
         } else {
-            _time->show();
-            _closeBtn->hide();
-
-            QPalette pe;
-            if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
-                pe.setColor(QPalette::ToolTipText, Qt::black);
-                _name->setPalette(pe);
-                pe.setColor(QPalette::BrightText, Qt::black);
-                _index->setPalette(pe);
-            } else if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
-                pe.setColor(QPalette::ToolTipText, Qt::white);
-                _name->setPalette(pe);
-                pe.setColor(QPalette::BrightText, Qt::white);
-                _index->setPalette(pe);
-            }
-        }
+        _time->show();
+        _closeBtn->hide();
+    }
         QFrame::paintEvent(pe);
     }
 
@@ -631,16 +520,19 @@ private:
     QString _bg;
     DLabel *_index;
     ListPic *_thumb;
+    QSvgWidget *m_pSvgWidget;
     DLabel *_name;
     DLabel *_time;
     QPixmap _play;
     PlayItemInfo _pif;
-    //FloatingButton *_closeBtn;
     DFloatingButton *_closeBtn;
     QListWidget *_listWidget {nullptr};
     bool _hovered {false};
     PlaylistWidget *_playlist{nullptr};
     bool m_bIsSelect = false;
+    QGraphicsOpacityEffect *m_opacityEffect {nullptr};
+    QGraphicsOpacityEffect *m_opacityEffect_1 {nullptr};
+    QColor m_highlightColor;
 };
 
 class MainWindowListener: public QObject
@@ -660,8 +552,7 @@ protected:
                     m_lastPoint = me->globalPos();
 
                     QTimer::singleShot(200, this, [ = ] {
-                        if (!m_bClicked)
-                        {
+                        if (!m_bClicked) {
                             return;
                         }
                         m_bClicked = false;
@@ -670,10 +561,8 @@ protected:
 
                         if (mw->insideResizeArea(m_lastPoint))
                             return;
-                        if (plw->state() == PlaylistWidget::Opened && !plw->underMouse())
-                        {
+                        if (plw->state() == PlaylistWidget::Opened && !plw->underMouse()) {
                             mw->requestAction(ActionFactory::ActionKind::TogglePlaylist);
-                            mw->set_playlistopen_clicktogglepause(true);
                         }
                     });
                 }
@@ -711,13 +600,45 @@ private:
     QPoint m_lastPoint;
 };
 
+/**
+ * @brief 获取播放列表内的所有鼠标事件
+ *
+*/
+class MouseEventListener: public QObject
+{
+public:
+    explicit MouseEventListener(QObject *parent): QObject(parent) {}
+    void setListWidget(DListWidget* listWidget)
+    {
+        m_pListWidget = listWidget;
+    }
+
+protected:
+    bool eventFilter(QObject *obj, QEvent *event)
+    {
+        if (event->type() == QEvent::MouseButtonPress) {
+            QMouseEvent *pMouseEvent = static_cast<QMouseEvent *>(event);
+            if (pMouseEvent->buttons() == Qt::LeftButton && !m_pListWidget->itemAt(pMouseEvent->pos())) {
+                PlayItemWidget *pItem = reinterpret_cast<PlayItemWidget *>(m_pListWidget->itemWidget(m_pListWidget->currentItem()));
+                if(pItem)
+                {
+                    pItem->setBIsSelect(false); // 点击播放列表空白处，取消item选中效果
+                    m_pListWidget->update();
+                }
+            }
+        }
+
+        return QObject::eventFilter(obj, event);
+    }
+private:
+    DListWidget* m_pListWidget;
+};
+
 PlaylistWidget::PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
     : QWidget(mw), _engine(mpv), _mw(static_cast<MainWindow *>(mw))
 {
     bool composited = CompositingManager::get().composited();
     setAttribute(Qt::WA_TranslucentBackground, false);
-    //NOTE: set fixed will affect geometry animation
-    //setFixedWidth(220);
     this->setObjectName(PLAYLIST_WIDGET);
 
     paOpen = nullptr;
@@ -730,7 +651,7 @@ PlaylistWidget::PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
     setLayout(mainVLayout);
 
     QHBoxLayout *mainLayout = new QHBoxLayout();
-    mainLayout->setContentsMargins(10, 0, 0, 0);
+    mainLayout->setContentsMargins(10, 0, 10, 0);
     mainLayout->setSpacing(0);
     mainLayout->setAlignment(Qt::AlignLeft | Qt::AlignTop);
 
@@ -809,7 +730,6 @@ PlaylistWidget::PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
     connect(m_pClearButton, &QPushButton::clicked, _engine, &PlayerEngine::clearPlaylist);
 
     left->setContentsMargins(36, 0, 0, 0);
-//    _title->setContentsMargins(0, 0, 0, 0);
     m_pClearButton->setContentsMargins(0, 0, 0, 70);
     _num->setContentsMargins(0, 0, 0, 0);
 
@@ -844,6 +764,11 @@ PlaylistWidget::PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
     _playlist->viewport()->setAcceptDrops(true);
     _playlist->setDragEnabled(true);
 
+    MouseEventListener* pListener = new MouseEventListener(this);
+    pListener->setListWidget(_playlist);
+    _playlist->viewport()->installEventFilter(pListener);
+    this->installEventFilter(pListener);
+
     connect(_playlist, &DListWidget::itemClicked, this, &PlaylistWidget::slotShowSelectItem);
     connect(_playlist, &DListWidget::currentItemChanged, this, &PlaylistWidget::OnItemChanged);
 
@@ -977,7 +902,6 @@ void PlaylistWidget::updateItemStates()
 {
     qInfo() << __func__ << _playlist->count() << "current = " << _engine->playlist().current();
 
-    //int len = _playlist->count();
     for (int i = 0; i < _playlist->count(); i++) {
         auto piw = dynamic_cast<PlayItemWidget *>(_playlist->itemWidget(_playlist->item(i)));
 
@@ -996,12 +920,7 @@ void PlaylistWidget::updateItemStates()
 
             }
         }
-
-//        if (old != piw->state()) {
-////            piw->setStyleSheet(piw->styleSheet());
-//        }
     }
-
 }
 
 void PlaylistWidget::showItemInfo()
@@ -1025,9 +944,9 @@ void PlaylistWidget::openItemInFM()
 
 void PlaylistWidget::removeClickedItem(bool isShortcut)
 {
-    if (isShortcut) {
+    if (isShortcut && isVisible()) {
         for (int i = 0; i < _playlist->count(); i++) {
-            auto piw = dynamic_cast<PlayItemWidget *>(_playlist->itemWidget(_playlist->item(i)));
+            PlayItemWidget * piw = dynamic_cast<PlayItemWidget *>(_playlist->itemWidget(_playlist->item(i)));
             qInfo() << piw->getBIsSelect();
             if (piw->getBIsSelect()) {
                 _engine->playlist().remove(i);
@@ -1037,7 +956,7 @@ void PlaylistWidget::removeClickedItem(bool isShortcut)
     }
 
     if (!_clickedItem) return;
-    auto piw = dynamic_cast<PlayItemWidget *>(_clickedItem);
+    PlayItemWidget * piw = dynamic_cast<PlayItemWidget *>(_clickedItem);
     if (piw) {
         qInfo() << __func__;
         for (int i = 0; i < _playlist->count(); i++) {
@@ -1165,7 +1084,6 @@ void PlaylistWidget::slotRowsMoved()
     ev->acceptProposedAction();
 }*/
 
-
 void PlaylistWidget::contextMenuEvent(QContextMenuEvent *cme)
 {
     bool on_item = false;
@@ -1397,16 +1315,23 @@ void PlaylistWidget::togglePopup(bool isShortcut)
         return ;
     }
 
-    auto main_rect = _mw->rect();
+    QRect main_rect = _mw->rect();
 #ifdef USE_DXCB
-    auto view_rect = main_rect;
+    QRect view_rect = main_rect;
 #else
-    auto view_rect = main_rect.marginsRemoved(QMargins(1, 1, 1, 1));
+    QRect view_rect = main_rect.marginsRemoved(QMargins(1, 1, 1, 1));
 #endif
-//    QRect fixed((10), (view_rect.height() - 394),
-//                view_rect.width() - 20, (384 - 70));
-    QRect fixed((10), (view_rect.height() - (TOOLBOX_SPACE_HEIGHT + TOOLBOX_HEIGHT + 10)),
-                view_rect.width() - 20, TOOLBOX_SPACE_HEIGHT + 10);
+
+    QRect fixed;
+    if(CompositingManager::get().platform() == X86) {
+        fixed.setRect(10, (view_rect.height() - (TOOLBOX_SPACE_HEIGHT + TOOLBOX_HEIGHT + 10)),
+                      view_rect.width() - 20, TOOLBOX_SPACE_HEIGHT + 10);
+
+    }
+    else {
+        fixed.setRect(10, (view_rect.height() - (TOOLBOX_SPACE_HEIGHT + TOOLBOX_HEIGHT + 10) + 5),
+                             view_rect.width() - 20, TOOLBOX_SPACE_HEIGHT + 10);
+    }
 
     QRect shrunk = fixed;
     shrunk.setHeight(0);
@@ -1470,6 +1395,7 @@ void PlaylistWidget::togglePopup(bool isShortcut)
         _state = State::Opened;
         emit stateChange(isShortcut);
         setGeometry(fixed);
+        _playlist->setAttribute(Qt::WA_TransparentForMouseEvents, false);
 #endif
     }
 }
@@ -1480,17 +1406,8 @@ void PlaylistWidget::paintEvent(QPaintEvent *pe)
     painter.setRenderHint(QPainter::Antialiasing);
     QRectF bgRect;
     bgRect.setSize(size());
-    const QPalette pal = QGuiApplication::palette();//this->palette();
-    //QColor bgColor = pal.color(QPalette::ToolTipBase);
-
     QPainterPath pp;
     pp.addRoundedRect(bgRect, 18, 18);
-    if (_title && _num) {
-        _title->setForegroundRole(DPalette::ToolTipText);
-        _num->setForegroundRole(DPalette::BrightText);
-    }
-
-
     QWidget::paintEvent(pe);
 }
 
@@ -1502,21 +1419,9 @@ void PlaylistWidget::resizeEvent(QResizeEvent *ev)
 #else
     auto view_rect = main_rect.marginsRemoved(QMargins(1, 1, 1, 1));
 #endif
-//#ifdef __aarch64__
-//    QRect fixed(15, (view_rect.height() - 394),
-//                view_rect.width() - 20, (384 - 100));
-
-////    _playlist->setFixedWidth(width() - 235);
-//    //_playlist->setFixedWidth(fixed.width() - 235);
-//    _playlist->setFixedSize(fixed.width() - 221, fixed.height());
-//    move(fixed.topLeft() - QPoint(10, 0));
-//#else
     QRect fixed((view_rect.width() - 10), (view_rect.height() - 394),
                 view_rect.width() - 20, (384 - 70));
-
-//    _playlist->setFixedWidth(width() - 235);
     _playlist->setFixedWidth(fixed.width() - 205);
-//#endif
     emit sizeChange();
 
     QTimer::singleShot(100, this, &PlaylistWidget::batchUpdateSizeHints);
