@@ -373,6 +373,11 @@ public:
      */
     void setBtnFocusSign(bool);
 
+    VolumeSlider *volumeSlider()
+    {
+        return m_pVolSlider;
+    }
+
     /////add for unit test/////
     DButtonBoxButton *playBtn() {return m_pPlayBtn;}
     DButtonBoxButton *prevBtn() {return m_pPrevBtn;}
@@ -397,6 +402,10 @@ public slots:
      * @brief setthumbnailmode 设置胶片进度条的模式
      */
     void setthumbnailmode();
+    /**
+     * @brief updateFullState 更新全屏状态下工具栏状态
+     */
+    void updateFullState();
 
 signals:
     /**
@@ -409,6 +418,10 @@ signals:
      * @param bMute 静音状态
      */
     void sigMuteStateChanged(bool &bMute);
+    /**
+      * @brief 功能不支持信号
+      */
+    void sigUnsupported();
 
 protected slots:
     /**
@@ -428,10 +441,7 @@ protected slots:
      * @brief updatePlayState 更新不同播放状态下工具栏状态
      */
     void updatePlayState();
-    /**
-     * @brief updateFullState 更新全屏状态下工具栏状态
-     */
-    void updateFullState();
+
     /**
      * @brief updateMovieProgress 更新影片进度条
      */
@@ -447,7 +457,7 @@ protected slots:
      */
     void progressHoverChanged(int v);
     /**
-     * @brief updateHoverPreview 更新悬停时间进度
+     * @brief updateHoverPreview 更新悬停时预览缩略图
      * @param url 文件url
      * @param secs 当前时间
      */
@@ -528,6 +538,11 @@ protected:
      * @param event 显示事件
      */
     void showEvent(QShowEvent *event) override;
+    /**
+     * @brief paintEvent 重绘事件函数
+     * @param event 重绘事件
+     */
+    void paintEvent(QPaintEvent *event) override;
     /**
      * @brief resizeEvent 窗口大小变化事件函数
      * @param event 大小变化事件
@@ -551,10 +566,6 @@ private:
      * @brief setup 初始化工具栏布局
      */
     void setup();
-    /**
-     * @brief updateTimeLabel 界面显示或大小变化时更新控件显示状态
-     */
-    void updateTimeLabel();
     /**
      * @brief updateToolTipTheme 更新按钮悬浮框主题
      * @param btn 对应的按钮
@@ -595,16 +606,14 @@ private:
     VolumeSlider *m_pVolSlider;          ///音量条控件窗口
     ViewProgBar *m_pViewProgBar;         ///胶片模式进度条窗口
     DMRSlider *m_pProgBar;               ///滑动条模式进度条窗口
-    ThumbnailPreview *m_pPreviewer;      ///胶片模式视图
-    SliderTime *m_pPreviewTime;          ///鼠标hover进度条时显示在进度条上方的时间控件（非鼠标悬停显示预览时）
+    ThumbnailPreview *m_pPreviewer;      ///鼠标悬停时进度条预览胶片控件
+    SliderTime *m_pPreviewTime;          ///鼠标悬停时进度条预览时间控件
 
-    DButtonBoxButton *m_pPlayBtn;        ///播放按钮
-    DButtonBoxButton *m_pPrevBtn;        ///上一个按钮
-    DButtonBoxButton *m_pNextBtn;        ///下一个按钮
+    ButtonBoxButton *m_pPlayBtn;        ///播放按钮
+    ButtonBoxButton *m_pPrevBtn;        ///上一个按钮
+    ButtonBoxButton *m_pNextBtn;        ///下一个按钮
     DButtonBox *m_pPalyBox;              ///按钮组
     VolumeButton *m_pVolBtn;             ///音量按钮
-    //TODO(xxxpengfei):字幕按钮没用，请在1050前去掉
-    ToolButton *m_pSubBtn;               ///字幕按钮
     ToolButton *m_pListBtn;              ///播放列表按钮
     ToolButton *m_pFullScreenBtn;        ///全屏按钮
 
@@ -632,6 +641,8 @@ private:
     bool m_bAnimationFinash;        ///动画是否完成
     bool m_bCanPlay;                ///判断是否能进行曲目切换的标志位
     bool m_bSetListBtnFocus;        ///设置播放列表按钮焦点标志位
+
+    float m_processAdd;
 };
 /**
  * @brief The viewProgBarLoad class
@@ -688,7 +699,7 @@ signals:
     /**
      * @brief finished 线程结束信号
      */
-    void finished();
+//    void finished();
 
 protected:
     void run();
