@@ -223,6 +223,22 @@
         <source>Default play mode</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Decoding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto select (Recommended)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hardware decoding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Software decoding</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UrlDialog</name>
@@ -469,7 +485,7 @@
     </message>
     <message>
         <source>No device found</source>
-        <translation>Ingen enhet hittades</translation>
+        <translation type="vanished">Ingen enhet hittades</translation>
     </message>
     <message>
         <source>Open folder</source>
@@ -477,7 +493,7 @@
     </message>
     <message>
         <source>All videos (%1)</source>
-        <translation>Alla videos (%1)</translation>
+        <translation type="vanished">Alla videos (%1)</translation>
     </message>
     <message>
         <source>Stereo</source>
@@ -563,10 +579,6 @@
         <source>No video file found</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Film screenshot</source>
         <translation>Ta en skärmbild</translation>
@@ -623,26 +635,34 @@
         <source>The CD/DVD has been ejected</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>All videos (*)(%2 %1)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Auto</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Open</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Close</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Please exit smart dock</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Cannot play the disc</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to adjust the subtitle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The action is not supported in this video</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All (*)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio (%1)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video (%1)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>dmr::MovieInfo</name>
@@ -757,6 +777,10 @@
         <source>%1hz</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 bps</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>dmr::MpvProxy</name>
@@ -789,10 +813,6 @@
 </context>
 <context>
     <name>dmr::Settings</name>
-    <message>
-        <source>%1/Movie%2.jpg</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>%1/Movie%2(%3).jpg</source>
         <translation type="unfinished"></translation>
@@ -846,7 +866,7 @@
     </message>
     <message>
         <source>Subtitles</source>
-        <translation>Undertexter</translation>
+        <translation type="vanished">Undertexter</translation>
     </message>
     <message>
         <source>Playlist</source>
@@ -890,7 +910,7 @@
     </message>
     <message>
         <source>Mute</source>
-        <translation type="unfinished">Tysta</translation>
+        <translation type="obsolete">Tysta</translation>
     </message>
     <message>
         <source>sub</source>
